-- tabulka fakult
CREATE TABLE fakulty(
	fakulta_id SERIAL PRIMARY KEY,
	nazev VARCHAR,
	nazev_en VARCHAR,
	zkratka VARCHAR,
	url VARCHAR,
	pocet INTEGER NOT NULL DEFAULT 0,
	shib_id VARCHAR
);
CREATE INDEX fakulty_id_idx ON fakulty USING hash (fakulta_id);



-- tabulka spravcu 
CREATE TABLE spravci(
	titul_pred VARCHAR,
	jmeno VARCHAR NOT NULL,
	prijmeni VARCHAR NOT NULL,
	titul_za VARCHAR,
	pid INTEGER PRIMARY KEY,
	login VARCHAR UNIQUE,
	email VARCHAR,
	je_admin BOOL DEFAULT FALSE,
	fakulta INTEGER REFERENCES fakulty ON DELETE SET NULL ON UPDATE CASCADE
);
CREATE INDEX spravci_pid_idx ON spravci USING hash (pid);
CREATE INDEX spravci_login_idx ON spravci USING hash (login);

-- zakladni tabulka reprezentujici zdroje
CREATE TABLE zdroje(
	zdroj_id SERIAL PRIMARY KEY,
	nazev VARCHAR,
	nazev_extra_cz VARCHAR,
	zkratka VARCHAR,
	odkaz VARCHAR,
	odkaz_extra_cz VARCHAR,
	odkaz_onelog_en VARCHAR,
	odkaz_onelog_cz VARCHAR,
	vytvoren DATE NOT NULL DEFAULT '2006-1-1',
	modifikace TIMESTAMP (0) WITHOUT TIME ZONE,
	expirace DATE,
	jazyk VARCHAR,
	typ INTEGER NOT NULL DEFAULT 0, -- typ zdroje
	info_strucne VARCHAR,
	info_strucne_en VARCHAR,
	info_podrobne TEXT,
	info_podrobne_chyba TEXT,
	info_podrobne_en TEXT,
	info_podrobne_en_chyba TEXT,
	producent_nazev VARCHAR, 
	producent_odkaz VARCHAR,
	financovani TEXT, 
	licence TEXT,
	aktivni BOOLEAN NOT NULL DEFAULT 't',
	novinky BOOLEAN NOT NULL DEFAULT 't',
	povoleny BOOLEAN NOT NULL DEFAULT 't',
	retrospektiva BOOLEAN NOT NULL DEFAULT 'f',
	fakulty_odkazy BOOLEAN NOT NULL DEFAULT 'f',
	rss BOOLEAN NOT NULL DEFAULT 'f',
	kontrola_expirace BOOLEAN NOT NULL DEFAULT 'f',
	zamek INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	zamek_cas TIMESTAMP (0) WITHOUT TIME ZONE,
	multioborovy BOOLEAN NOT NULL DEFAULT 't',
	kategorie INTEGER NOT NULL DEFAULT 0,
	zarazeni INTEGER NOT NULL DEFAULT 0, 
	odpovedny_spravce INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	kontaktni_osoba INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	verde_id VARCHAR,
	ezproxy_odkaz BOOLEAN NOT NULL DEFAULT 't',
	sfx BOOLEAN NOT NULL DEFAULT 'f',
	sfx_popis TEXT,
	sfx_popis_en TEXT,
	shib BOOLEAN NOT NULL DEFAULT 'f',
	shib_odkaz VARCHAR,
	shib_odkaz_en VARCHAR,
	shib_popis TEXT,
	shib_popis_en TEXT,
	linker_db VARCHAR,
	vyhledavac_db VARCHAR,
	linker_manualni_nahrani BOOLEAN NOT NULL DEFAULT 'f',
	aktivni_od DATE,
	dostupnost VARCHAR,
	kolekce TEXT,
	zdroj_zdroj_rodic BOOLEAN NOT NULL DEFAULT 'f',
	zdroj_zdroj_potomek BOOLEAN NOT NULL DEFAULT 'f'
	
);
CREATE INDEX zdroje_id_idx ON zdroje USING hash (zdroj_id);


CREATE TABLE retrospektiva_zdroje (
	zdroj_id INTEGER REFERENCES zdroje ON DELETE CASCADE ON UPDATE CASCADE,
	zacatek DATE,
	konec DATE,
	poznamka VARCHAR,
	PRIMARY KEY(zdroj_id, zacatek, konec)
);
CREATE INDEX retrospektiva_zdroje_id_idx ON retrospektiva_zdroje (zdroj_id);



CREATE TABLE obory(
	obor_id SERIAL PRIMARY KEY,
	nazev VARCHAR,
	nazev_en VARCHAR,
	koren BOOLEAN NOT NULL DEFAULT 'f',
	pocet INTEGER NOT NULL DEFAULT 0
);
CREATE INDEX obory_id_idx ON obory USING hash (obor_id);



CREATE TABLE aktuality(
	aktualita_id SERIAL PRIMARY KEY,
	modifikace TIMESTAMP (0) WITHOUT TIME ZONE,
	datum DATE NOT NULL DEFAULT CURRENT_DATE,
	nazev VARCHAR,
	nazev_en VARCHAR,
	perex VARCHAR,
	perex_en VARCHAR,
	obsah TEXT,
	obsah_chyba TEXT,
	obsah_en TEXT,
	obsah_en_chyba TEXT,
	povolena BOOLEAN NOT NULL DEFAULT 't',
	rss BOOLEAN NOT NULL DEFAULT 'f',
	vytvoril INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE
);
CREATE INDEX aktuality_id_idx ON aktuality USING hash (aktualita_id);



-- tabulky realizujici vztahy
-- jedna faulta obsahuje vice zdroju, jeden zdroj patri do vice fakult 
CREATE TABLE zdroj_fakulta(
	zdroj_id INTEGER REFERENCES zdroje ON DELETE CASCADE ON UPDATE CASCADE, 
	fakulta_id INTEGER REFERENCES fakulty ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(zdroj_id, fakulta_id)
);


-- informace o nazvu zdroje, odkazu aj. pro jednotlive fakulty
CREATE TABLE zdroj_fakulta_info(
	zdroj_id INTEGER REFERENCES zdroje ON DELETE CASCADE ON UPDATE CASCADE, 
	fakulta_id INTEGER REFERENCES fakulty ON DELETE CASCADE ON UPDATE CASCADE,
	nazev_cs VARCHAR,
	nazev_en VARCHAR,
	odkaz_cs VARCHAR,
	odkaz_en VARCHAR,
	odkaz_onelog_cs VARCHAR,
	odkaz_onelog_en VARCHAR,
	PRIMARY KEY(zdroj_id, fakulta_id)
);



-- zdroj patri do vice oboru, obor ma vice zdroju 
CREATE TABLE zdroj_obor(
	zdroj_id INTEGER REFERENCES zdroje ON DELETE CASCADE ON UPDATE CASCADE,
	obor_id INTEGER REFERENCES obory ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(zdroj_id, obor_id)
);

-- obor muze mit podobory
CREATE TABLE obor_obor(
	obor_rodic INTEGER REFERENCES obory (obor_id) ON DELETE CASCADE ON UPDATE CASCADE,
	obor_potomek INTEGER REFERENCES obory (obor_id) ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(obor_rodic, obor_potomek)
);


-- casopisy 
CREATE TABLE casopisy(
	casopis_id SERIAL PRIMARY KEY,
	titul VARCHAR,
	nakladatel VARCHAR,
	e_issn VARCHAR,
	p_issn VARCHAR,
	klicova_slova TEXT,
	odkazy TEXT,
	typ INTEGER,
	typ_platby INTEGER,
	pristup INTEGER,
	recenze BOOLEAN NOT NULL DEFAULT 'f',
	prrv_issue INTEGER,
	prrv_volume INTEGER,
	prrv_year INTEGER,
	porv_issue INTEGER,
	porv_volume INTEGER,
	porv_year INTEGER,
	pohybliva_dostupnost INTEGER, -- mesicu
	dostupne BOOLEAN NOT NULL DEFAULT 't', -- dustupne "only"=t, "not"=f
	dostupnost VARCHAR,
	frekvence VARCHAR,
	komentar TEXT,
	aktivni BOOLEAN NOT NULL DEFAULT 't',
	smazat BOOLEAN NOT NULL DEFAULT 'f',
	kontrolovan BOOLEAN NOT NULL DEFAULT 'f',
	mu BOOLEAN NOT NULL DEFAULT 't',
	ezb BOOLEAN NOT NULL DEFAULT 't',
	in_ezb BOOLEAN NOT NULL DEFAULT 'f',
	ezbid INTEGER,
	expirace DATE,
	rss BOOLEAN NOT NULL DEFAULT 'f',
	kontrola_expirace BOOLEAN NOT NULL DEFAULT 'f',
	vytvoren DATE NOT NULL DEFAULT '2006-1-1',
	modifikace TIMESTAMP (0) WITHOUT TIME ZONE,
	odpovedny_spravce INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	kontaktni_osoba INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	zamek INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	zamek_cas TIMESTAMP (0) WITHOUT TIME ZONE,
	linker_db VARCHAR,
	aktivni_od DATE
);
CREATE INDEX casopisy_id_idx ON casopisy USING hash (casopis_id);



CREATE TABLE predmety( -- subjects
	predmet_id SERIAL PRIMARY KEY,
	predmet VARCHAR
);
CREATE INDEX predmety_id_idx ON predmety USING hash (predmet_id);



CREATE TABLE casopis_predmet(
	casopis_id INTEGER REFERENCES casopisy (casopis_id) ON DELETE CASCADE ON UPDATE CASCADE,
	predmet_id INTEGER REFERENCES predmety (predmet_id) ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(casopis_id, predmet_id)
);



CREATE TABLE casopis_fakulta(
	casopis_id INTEGER REFERENCES casopisy (casopis_id) ON DELETE CASCADE ON UPDATE CASCADE,
	fakulta_id INTEGER REFERENCES fakulty ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(casopis_id, fakulta_id)
);



CREATE TABLE knihy (
	kniha_id SERIAL PRIMARY KEY,
	id VARCHAR,
	titul VARCHAR,
	titul_extra_cz VARCHAR,
	odkaz VARCHAR,
	odkaz_extra_cz VARCHAR,
	odkaz_onelog_en VARCHAR,
	odkaz_onelog_cz VARCHAR,
	producent VARCHAR,
	producent_odkaz VARCHAR,
	vydavatel VARCHAR,
	vydavatel_odkaz VARCHAR,
	rok_vydani VARCHAR,
	misto_vydani VARCHAR,
	isbn VARCHAR,
	pocet_stran VARCHAR,
	strucny_popis VARCHAR,
	strucny_popis_en VARCHAR,
	popis TEXT,
	popis_en TEXT,
	poznamka TEXT,
	jazyk VARCHAR,
	expirace DATE,
	licence TEXT,
	financovani TEXT,
	obalka VARCHAR,
	rss BOOLEAN NOT NULL DEFAULT 'f',
	kategorie INTEGER NOT NULL DEFAULT 0,
	kontaktni_osoba INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	odpovedny_spravce INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	vytvoren DATE NOT NULL DEFAULT '2006-1-1',
  modifikace TIMESTAMP (0) WITHOUT TIME ZONE,
	zamek INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
  zamek_cas TIMESTAMP (0) WITHOUT TIME ZONE,
	povoleny BOOLEAN NOT NULL DEFAULT 't',
	aktivni BOOLEAN NOT NULL DEFAULT 't',
	novinky BOOLEAN NOT NULL DEFAULT 't',
	multioborovy BOOLEAN NOT NULL DEFAULT 't',
	zarazeni INTEGER NOT NULL DEFAULT 0, 
	kontrola_expirace BOOLEAN NOT NULL DEFAULT 'f',
	retrospektiva BOOLEAN NOT NULL DEFAULT 'f',
	verde_id VARCHAR,
	autori VARCHAR,
	nahled VARCHAR,
	linker_db VARCHAR,
	aktivni_od DATE

);
CREATE INDEX kniha_id_idx ON knihy USING hash (kniha_id);



CREATE TABLE kniha_obor (
  kniha_id INTEGER REFERENCES knihy (kniha_id) ON DELETE CASCADE ON UPDATE CASCADE,
	obor_id INTEGER REFERENCES obory ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(kniha_id, obor_id)
);



CREATE TABLE kniha_fakulta (
	kniha_id INTEGER REFERENCES knihy (kniha_id) ON DELETE CASCADE ON UPDATE CASCADE,
	fakulta_id INTEGER REFERENCES fakulty ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(kniha_id, fakulta_id)
);



CREATE TABLE retrospektiva_knihy (
	kniha_id INTEGER REFERENCES knihy ON DELETE CASCADE ON UPDATE CASCADE,
	zacatek DATE,
	konec DATE,
	poznamka VARCHAR,
	PRIMARY KEY(kniha_id, zacatek, konec)
);
CREATE INDEX kniha_retrospektiva_idx ON retrospektiva_knihy USING hash (kniha_id);


CREATE TABLE kniha_fakulta_info(
	kniha_id INTEGER REFERENCES knihy ON DELETE CASCADE ON UPDATE CASCADE, 
	fakulta_id INTEGER REFERENCES fakulty ON DELETE CASCADE ON UPDATE CASCADE,
	nazev_cs VARCHAR,
	nazev_en VARCHAR,
	odkaz_cs VARCHAR,
	odkaz_en VARCHAR,
	odkaz_onelog_cs VARCHAR,
	odkaz_onelog_en VARCHAR,
	PRIMARY KEY(kniha_id, fakulta_id)
);


CREATE TABLE soubory (
	soubor_id SERIAL PRIMARY KEY, 
	objekt_id INTEGER, 
	objekt_typ INTEGER, 
	jmeno VARCHAR, 
	datum TIMESTAMP (0) WITHOUT TIME ZONE NOT NULL DEFAULT LOCALTIMESTAMP (0), 
	popis VARCHAR, 
	popis_en VARCHAR,
	verejny BOOLEAN NOT NULL DEFAULT 'f', 
	zamek INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE, 
	zamek_cas TIMESTAMP (0) WITHOUT TIME ZONE
);
CREATE INDEX soubory_objekt_id ON soubory (objekt_id);
CREATE INDEX soubory_objekt_typ ON soubory (objekt_typ);


CREATE TABLE rss (
	id INTEGER PRIMARY KEY,
	rss VARCHAR,
	zamcen BOOLEAN NOT NULL DEFAULT 'f',
	uzivatelem INTEGER REFERENCES spravci (pid) ON DELETE SET NULL ON UPDATE CASCADE,
	cas TIMESTAMP (0) WITHOUT TIME ZONE
);

INSERT INTO rss (id, rss) VALUES ('1', 'rss');
INSERT INTO rss (id, rss) VALUES ('2', 'rss_en');
INSERT INTO rss (id, rss) VALUES ('3', 'rss_detail');
INSERT INTO rss (id, rss) VALUES ('4', 'rss_detail_en');


CREATE TABLE zdroj_zdroj (
	rodic_id INTEGER REFERENCES zdroje (zdroj_id) ON DELETE CASCADE ON UPDATE CASCADE,
	potomek_id INTEGER REFERENCES zdroje (zdroj_id) ON DELETE CASCADE ON UPDATE CASCADE,
	PRIMARY KEY(rodic_id, potomek_id)
);


CREATE TABLE zdroj_snippet (id SERIAL PRIMARY KEY, zdroj_id INTEGER REFERENCES zdroje ON DELETE CASCADE ON UPDATE CASCADE, snippet VARCHAR);

CREATE TABLE casopis_snippet (id SERIAL PRIMARY KEY, casopis_id INTEGER REFERENCES casopisy ON DELETE CASCADE ON UPDATE CASCADE, snippet VARCHAR);

CREATE TABLE kniha_snippet (id SERIAL PRIMARY KEY, kniha_id INTEGER REFERENCES knihy ON DELETE CASCADE ON UPDATE CASCADE, snippet VARCHAR);

