<?php

require_once("config.php");
require_once("constants.php");
require_once("functions.php");
require_once("functionsv2.php");

class dbQuery {

public static function processQuery($classname, $query, $params = null) {

	if ($params == null) {
		$result = pg_query($query);
	}
	else {
		$result = pg_query_params($query, $params);
	}
	
	$objects = array();

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {
			$objects[] = $classname::fromDbConstructor($row);
	}
		
	return $objects;
}

// deprecated! 
public static function processQueryv2($classname, $query, $params) {

	$result = pg_query_params($query, $params);
	$objects = array();

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {
		$objects[] = $classname::fromDbConstructor($row);
	}

	return $objects;
}

public static function getArray($pg_array) {

	return explode(",", trim($pg_array, "{}"));
}

public static function toArray($array) {

	$toreturn = "{";
	foreach($array as $item) {
		$toreturn .= $item . ",";
	}
	
	return trim($toreturn, ',')."}";
}

}


class obory {
	var $obory, $nazvy, $nazvy_en;

	function obory($obory) {
		$this->obory = $obory;
		
		foreach($this->obory as $obor) {
			$this->nazvy[$obor->id] = $obor->nazev;
			$this->nazvy_en[$obor->id] = $obor->nazev_en;

			foreach($obor->podobory as $podobor) {
				$this->nazvy[$podobor->id] = $podobor->nazev;
				$this->nazvy_en[$podobor->id] = $podobor->nazev_en;
			}
		}
	}

	public function getNazev($lang, $id) {
		return $lang == 'en' ? $this->nazvy_en[$id] : $this->nazvy[$id];
	}
}


class obor {
	var $id, $nazev, $nazev_en, $pocet, $koren, $podobory;

	// kontruktor
	function obor($id = -1, $nazev="", $nazev_en="", $pocet=0, $koren=true)
	{
		$this->id = $id;
		$this->nazev = $nazev;
		$this->nazev_en = $nazev_en;
		$this->pocet = $pocet;
		$this->koren = $koren;
		$this->podobory = array();
	}

	// trideni vracenych oboru
	private static function getPoradi($lang) {
		return $lang == 'en' ? 'nazev_en' : 'nazev';
	}

	public function getNazev($lang) {
		return $lang == 'en' ? $this->nazev_en : $this->nazev;
	}

	// kompletni strom
	public static function getObory($lang) {
		$obory = obor::getKoreny($lang);

		foreach($obory as $obor) {
			$obor->storePodobory($lang);
		}

		return $obory;
	}

	// korenove obory
	public static function getKoreny($lang) {
		$obory = array();
		$order = obor::getPoradi($lang);

		$query = "SELECT obor_id, nazev, nazev_en, pocet".
			" FROM obory WHERE koren='t' ORDER BY $order";

		$result_obory = pg_query($query);

		while ($row = pg_fetch_array($result_obory, NULL, PGSQL_ASSOC)) {

			array_push($obory, new obor($row['obor_id'], $row['nazev'], $row['nazev_en'], $row['pocet'], true));
		}

		return $obory;
	}

	// pridej podobor
	public function pridejPodobor($obor) {
		array_push($this->podobory, $obor);
	}

	// k oboru uloz jeho podobory
	public function storePodobory($lang) {

		$order = obor::getPoradi($lang);

		$query = "SELECT obory.obor_id, obory.nazev, obory.nazev_en, obory.pocet".
			" FROM obory, obor_obor".
			" WHERE (obor_obor.obor_rodic = '$this->id') AND".
			"	(obor_obor.obor_potomek = obory.obor_id)".
			" ORDER BY obory.$order";
		$result = pg_query($query);

		while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

			$this->pridejPodobor(new obor($row['obor_id'], $row['nazev'], $row['nazev_en'], $row['pocet'], false));

		}
	}
}


// predmet pouze pro casopisy
class predmet {
	var $id, $predmet, $aktivni;

	function predmet($id = "", $predmet = "")
	{
		$this->id = $id;
		$this->predmet = $predmet;
		$this->aktivni = false;
	}

	function setA()
	{
		$this->aktivni = true;
	}

	function unsetA()
	{
		$this->aktivni = false;
	}
}

class casopis {
	var $id, $ezbid, $nazev;

	function casopis($id = "", $ezbid = "", $nazev = "")
	{
		$this->id = $id;
		$this->ezbid = $ezbid;
		$this->nazev = $nazev;
	}
}

class zdrojv1 {
	var $zdroj_id, $zkratka, $odkaz, $info_strucne, $expirace, $kategorie,
		$nazev_extra_cz, $odkaz_onelog_en, $odkaz_onelog_cz, $odkaz_extra_cz,
		$ezproxy_odkaz;

	function zdrojv1($zdroj_id = "", $zkratka = "", $odkaz = "", 
		$info_strucne = "", $expirace = "", $kategorie = "", 
		$nazev_extra_cz = "", $odkaz_onelog_en = "", $odkaz_onelog_cz ="", 
		$odkaz_extra_cz = "", $ezproxy_odkaz = true)
	{

		$this->zdroj_id = $zdroj_id;
		$this->zkratka = $zkratka;
		$this->odkaz = $odkaz;
		$this->info_strucne = $info_strucne; 
		$this->expirace = $expirace;
		$this->kategorie = $kategorie;
		$this->nazev_extra_cz = $nazev_extra_cz;
		$this->odkaz_onelog_en = $odkaz_onelog_en;
		$this->odkaz_onelog_cz = $odkaz_onelog_cz;
		$this->odkaz_extra_cz =	$odkaz_extra_cz;
		$this->ezproxy_odkaz = $ezproxy_odkaz;

	}

}

class retrospektiva {
	var $denOd, $mesicOd, $rokOd, $denDo, $mesicDo, $rokDo, $poznamka;

	function retrospektiva($denOd="", $mesicOd="", $rokOd="", $denDo="", $mesicDo="", $rokDo="", $poznamka="")
	{

		$this->denOd = $denOd;
		$this->mesicOd = $mesicOd;
		$this->rokOd = $rokOd;
		$this->denDo = $denDo;
		$this->mesicDo = $mesicDo;
		$this->rokDo = $rokDo;
		$this->poznamka = $poznamka;
	}

	public function tisk()
	{
		return $this->denOd . $this->mesicOd . $this->rokOd . 
				    $this->denDo . $this->mesicDo . $this->rokDo .
						    $this->poznamka;
	}

	public function tiskOd() {
		if ($this->denOd != "") {
			return $this->denOd .".". $this->mesicOd .".". $this->rokOd;
		}
		else {
			return "&nbsp;";
		}
	}

	public function tiskDo() {
		if ($this->denDo != "") {
			return $this->denDo .".". $this->mesicDo .".". $this->rokDo;
		}
		else {
			return "&nbsp;";
		}
	}

	public function clear()
	{
		global $TOP_EXPIR_TEXT, $BOTTOM_EXPIR_TEXT;
		if (makeDate($this->rokOd, $this->mesicOd, $this->denOd) == 
			$BOTTOM_EXPIR_TEXT) {
				$this->denOd = "";
				$this->mesicOd = "";
				$this->rokOd = "";
			}

		if (makeDate($this->rokDo, $this->mesicDo, $this->denDo) ==
			$TOP_EXPIR_TEXT) {
				$this->denDo = "";
				$this->mesicDo = "";
				$this->rokDo = "";
			}
	}

	private function check()
	{
		if ($this->denOd == "") $this->denOd = "1";
		if ($this->denDo == "") $this->denDo = "31";
		if ($this->mesicOd == "") $this->mesicOd = "1";
		if ($this->mesicDo == "") $this->mesicDo = "12";
	}

	public function getDbOd()
	{ 
		if ($this->rokOd == "") return "";
		$this->check();
		return makeDate($this->rokOd, $this->mesicOd, $this->denOd);
	}

	public function getDbDo()
	{
		if ($this->rokDo == "") return "";
		$this->check();
		return makeDate($this->rokDo, $this->mesicDo, $this->denDo);
	}

	public function compare()
	{
		if (compareCurrentDate(makeDate($this->rokOd, $this->mesicOd, $this->denOd),
			makeDate($this->rokDo, $this->mesicDo, $this->denDo)) > 0) return false;
		else return true;
	}
}

?>
