<?php

require_once("classes.php");

class fakulta {
	
public $fid;
public $fakulta_id;
public $id; 
public $nazev; 
public $nazev_en; 
public $zkratka; 
public $pocet; 
public $url;
public $shib_id;

const NEW_FAC = -1;

public function __construct($fakulta_id, $nazev = "", $nazev_en = "",
 $shib_id = '', $zkratka = "", $pocet = 0, $url ="")
{
	$this->fid = $fakulta_id;
	$this->fakulta_id = $fakulta_id;
	$this->id = $fakulta_id;
	$this->nazev = $nazev;
	$this->nazev_en = $nazev_en;
	$this->zkratka = $zkratka;
	$this->pocet = $pocet;
	$this->url = $url;
	$this->shib_id = $shib_id;
}


protected static function fromDbConstructor($row) {

	$fakulta = new fakulta(
		$row['fakulta_id'],
		$row['nazev'],
		$row['nazev_en'],
		$row['shib_id'],
		$row['zkratka'],
		$row['pocet'],
		$row['url']);
		
	return $fakulta;
}


public function store() {
	
	$values = array(
		$this->nazev,
		$this->nazev_en,
		$this->zkratka,
		$this->url,
		$this->pocet,
		$this->shib_id);


	if ($this->id == fakulta::NEW_FAC) {

		$query = "INSERT INTO fakulty (
			nazev, 
			nazev_en,
			zkratka,
			url,
			pocet,
			shib_id) VALUES ($1, $2, $3, $4, $5, $6)";

	}
	else {
		$query = "UPDATE fakulty SET
			nazev=$1, 
			nazev_en=$2, 
			zkratka=$3, 
			url=$4, 
			pocet=$5, 
			shib_id=$6 WHERE fakulta_id=$7";
		$values[] = $this->id;
	}

	$result = pg_query_params($query, $values);

	if ($this->id == fakulta::NEW_FAC) {
		$this->id = getIdFromDB('fakulty_fakulta_id_seq');
	}

	return $this->id;
}
		



		 	
		


private static function getPoradi($lang, $zkratka = false) {

	if ($zkratka) return 'zkratka';
	else return $lang == 'en' ? 'nazev_en' : 'nazev';
}

public function getNazev($lang) {
	return $lang == 'en' ? $this->nazev_en : $this->nazev;
}

public function getZkratka() {
	return $this->zkratka;
}

public static function newFakulta() {
	return new fakulta(fakulta::NEW_FAC);
}

// FIX IT v budoucnu o dphp 5.3.0 prejit na tridu dbQuery
public static function processQuery($query) {

	$result = pg_query($query);

	$objects = array();

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

		$objects[] = self::fromDbConstructor($row);
	}

	return $objects;
}

// FIX IT v budoucnu o dphp 5.3.0 prejit na tridu dbQuery
public static function processQueryv2($query, $params) {

	$result = pg_query_params($query, $params);

	$objects = array();

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

		$objects[] = self::fromDbConstructor($row);
	}

	return $objects;
}


public static function getFakulty($lang, $zkratka = false, $order = null) {

	if ($order == null)
		$order = self::getPoradi($lang);

	$query = "SELECT * FROM fakulty ORDER BY $order";
		
	return self::processQuery($query);
}	

public static function getFakultyByZdroj($lang, $zdroj_id, $zkratka = false) {

	$order = self::getPoradi($lang);

	$query = "SELECT * FROM fakulty, zdroj_fakulta".
		" WHERE (zdroj_fakulta.zdroj_id = $1) AND".
		"	(zdroj_fakulta.fakulta_id = fakulty.fakulta_id)".
		" ORDER BY fakulty.$order";
	$params = array($zdroj_id);

	return self::processQueryv2($query, $params);
}

public static function getFakultyByCasopis($lang, $casopis_id, 
	$zkratka = false) {

	$order = self::getPoradi($lang);

	$query = "SELECT * FROM fakulty, casopis_fakulta".
		" WHERE (casopis_fakulta.casopis_id = $1) AND".
		"	(casopis_fakulta.fakulta_id = fakulty.fakulta_id)".
		" ORDER BY fakulty.$order";
	$params = array($casopis_id);

	return self::processQueryv2($query, $params);
}

public static function getFakultyByKniha($lang, $kniha_id, $zkratka = false) {

	$order = self::getPoradi($lang);

	$query = "SELECT * FROM fakulty, kniha_fakulta".
		" WHERE (kniha_fakulta.kniha_id = $1) AND".
		"	(kniha_fakulta.fakulta_id = fakulty.fakulta_id)".
		" ORDER BY fakulty.$order";
	$params = array($kniha_id);

	return self::processQueryv2($query, $params);
}

public static function getFakulta($id) {

	$query = "SELECT * FROM fakulty WHERE fakulta_id = $1";
	$params = array($id);

	$vals = self::processQueryv2($query, $params);

	return count($vals) == 1 ? $vals[0] : null;
}

public static function getFakultaByShibId($shib_id) {

	$query = "SELECT * FROM fakulty WHERE shib_id = $1";
	$params = array($shib_id);

	$vals = self::processQueryv2($query, $params);

	return count($vals) == 1 ? $vals[0] : null;
}


public function getZkratkaLink($lang, $where) {

	global $MY_URL;

	return "<a href=\"$MY_URL/$where/fakulta.php?lang=$lang&$this->id\">".
		$this->zkratka."</a>";

}

public function isBad() {

	if ($this->id === fakulta::NEW_FAC) return false;
	else {
		if ($this->nazev == '' || $this->nazev_en == '') return true;	
	}

	return false;
}

}

// pomocne tridy pro fakulty a jejich rychlesjsi zpracovavani
// v podstate hashe v pameti, ktere asociuji identifikator a nazvy a zkratky
class fakulty {

public $fakulty;
public $nazvy;
public $nazvy_en; 
public $zkratky; 
public $pocet; 
public $shib_ids; 
public $ids;

public function __construct($fakulty) {
	$this->fakulty = $fakulty;
	$this->pocet = count($fakulty);
		
	foreach($this->fakulty as $fakulta) {
		$this->nazvy[$fakulta->id] = $fakulta->nazev;
		$this->nazvy_en[$fakulta->id] = $fakulta->nazev_en;
		$this->zkratky[$fakulta->id] = $fakulta->zkratka;
		$this->ids[] = $fakulta->fakulta_id;
		$this->shib_ids[] = $fakulta->shib_id;
	}
}

public function getNazev($lang, $id) {
	return $lang == 'en' ? $this->nazvy_en[$id] : $this->nazvy[$id];
}

public function getZkratka($id) {
	return isset($this->zkratky[$id]) ? $this->zkratky[$id] : '';
}

public function printZkratky($lang, $where, $link = true) {

	$str = '';

	if ($link) {
		foreach($this->fakulty as $fakulta) {
			$str .= $fakulta->getZkratkaLink($lang, $where). ', ';
		}
	}
	else {
		foreach($this->fakulty as $fakulta) {
			$str .= $fakulta->zkratka.', ';
		}
	}

	return $str;
}


}


// TO FIX -- prepsat na verzi 2
// ifnromace o vztahu fakulty, daneho zdroje a jednotlivych odkazu 
class fakulta_info {
	var $id, $fid, $nazev_cs, $nazev_en, $odkaz_cs, $odkaz_en, $odkaz_onelog_cs, 
		$odkaz_onelog_en, $typ, $odkaz_shib_cs, $odkaz_shib_en;

	function fakulta_info($typ, $fid=-1, $nazev_cs="", $nazev_en="", 
		$odkaz_cs="", $odkaz_en="", $odkaz_onelog_cs="", $odkaz_onelog_en="",
		$odkaz_shib_cs = '', $odkaz_shib_en = '')
	{
		$this->typ = $typ;
		$this->fid = $fid;
		$this->id = $fid;
		$this->nazev_cs = $nazev_cs;
		$this->nazev_en = $nazev_en;
		$this->odkaz_cs = $odkaz_cs;
		$this->odkaz_en = $odkaz_en;
		$this->odkaz_onelog_cs = $odkaz_onelog_cs;
		$this->odkaz_onelog_en = $odkaz_onelog_en;
		$this->odkaz_shib_cs = $odkaz_shib_cs;
		$this->odkaz_shib_en = $odkaz_shib_en;
	}

	public function getOdkaz($lang) {
		return getLink($lang, $this->odkaz_en, $this->odkaz_cs);
	}

	public function getOneLog($lang) {
		return getOneLogLink($lang, $this->odkaz_onelog_en, $this->odkaz_onelog_cs);
	}

	public function getShib($lang) {
		return getShibLink($lang, $this->odkaz_shib_en, $this->odkaz_shib_cs);
	}


	public static function getFakulty($typ, $zdroj_id, $fakulty = null) {

		$ident = fakulta_info::getTable($typ);

		$query = "SELECT * FROM ".$ident."_fakulta_info WHERE zdroj_id = '$zdroj_id'";
		$result = pg_query($query);

		$vysledek = array();

		while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

			array_push($vysledek, 
				new fakulta_info(
					$typ, 
					$row['fakulta_id'], 
					$row['nazev_cs'], 
					$row['nazev_en'], 
					$row['odkaz_cs'], 
					$row['odkaz_en'], 
					$row['odkaz_onelog_cs'], 
					$row['odkaz_onelog_en'], 
					$row['odkaz_shib_cs'], 
					$row['odkaz_shib_en']));
		}

		setlocale(LC_ALL, "cs_CZ.utf8");

		//sort($vysledek, 

		return $vysledek;
	}


	function is_empty() {
		if (trim($this->nazev_cs) == "" &&
			trim($this->nazev_en) == "" &&
			trim($this->odkaz_cs) == "" &&
			trim($this->odkaz_en) == "" &&
			trim($this->odkaz_onelog_cs) == "" &&
			trim($this->odkaz_onelog_en) == "" &&
		 	trim($this->odkaz_shib_cs) == "" &&
			trim($this->odkaz_shib_en) == "")	return true;
		else return false;
	}

	function isOdkaz() {
		if (trim($this->odkaz_cs) == "" && 
			trim($this->odkaz_en) == "") return true;
		else return false;
	}

	function isVzdalenyOdkaz() {
		if (trim($this->odkaz_onelog_cs) == "" && 
			trim($this->odkaz_onelog_en) == "") return true;
		else return false;
	}

	function isShibOdkaz() {
		if (trim($this->odkaz_shib_cs) == "" &&
			trim($this->odkaz_shib_en) == "") return true;
		else return false;
	}



	static function getTable($typ) 
	{
		global $BOOK, $SOURCE, $MAGAZINE;

		switch ($typ) {
		case $SOURCE: return "zdroj";
		case $BOOK: return "kniha";
		case $MAGAZINE: return "casopis";
		default: return "zdroj";
		}
	}

	function dbdelete($id) {
		$ident = fakulta_info::getTable($this->typ);

		$query = "DELETE FROM ".$ident."_fakulta_info".
			" WHERE ".$ident."_id = '$id' AND fakulta_id='$this->fid'";
		pg_query($query);
	}

	function dbstore($id) {
		$ident = fakulta_info::getTable($this->typ);	

		$query = "SELECT ".$ident."_id FROM ".$ident."_fakulta_info ". 
			" WHERE ".$ident."_id = '$id' AND fakulta_id='$this->fid'";
		$result = pg_query($query);

		if (pg_num_rows($result) > 0) {

			$query = "UPDATE ".$ident."_fakulta_info SET". 
				" nazev_cs = '$this->nazev_cs',".
			  " nazev_en = '$this->nazev_en',".
			  "	odkaz_cs = '$this->odkaz_cs',".
				" odkaz_en = '$this->odkaz_en',".
				" odkaz_onelog_cs = '$this->odkaz_onelog_cs',".
				" odkaz_onelog_en = '$this->odkaz_onelog_en'".
				" odkaz_shib_cs = '$this->odkaz_shib_cs'".
				" odkaz_shib_en = '$this->odkaz_shib_en'".
				" WHERE ".$ident."_id = '$id' AND fakulta_id='$this->fid'";
		}
		else {
			$query = "INSERT INTO ".$ident."_fakulta_info".
				" (".$ident."_id, fakulta_id, nazev_cs, nazev_en, odkaz_cs, odkaz_en,".
			 	"	odkaz_onelog_cs, odkaz_onelog_en, odkaz_shib_cs, odkaz_shib_en) VALUES".
				" ('$id', '$this->fid',".
				" '$this->nazev_cs', '$this->nazev_en', '$this->odkaz_cs',".
				" '$this->odkaz_en', '$this->odkaz_onelog_cs',".
				"	'$this->odkaz_onelog_en', '$this->odkaz_shib_cs',".
				" '$this->odkaz_shib_en')";
		}

		pg_query($query);
	}
}

