<?php

require_once("functions.php");

function get_lock_table($typ) 
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK, $FILE;

	switch ($typ) {
	case $SOURCE: return "zdroje";
	case $MAGAZINE: return "casopisy";
	case $NEWS: return "aktuality";
	case $BOOK: return "knihy";
	case $FILE: return "soubory";
	default: return "zdroje";
	}
}


function get_lock_rowid($typ)
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK, $FILE;
	
	switch ($typ) {
	case $SOURCE: return "zdroj_id";
	case $MAGAZINE: return "casopis_id";
	case $NEWS: return "aktualita_id";
	case $BOOK: return "kniha_id";
	case $FILE: return "soubor_id";
	default: return "zdroj_id";
	}

}

/* ---- part of rights management is also locking ---- */
function lock($pid, $id, $typ, $skript)
{
	global $LOG_DBE, $LOG_INF, $LOG_LCK;

	$table = get_lock_table($typ);
	$rowid = get_lock_rowid($typ);

	//$TRANSACTION_LOCKING = true;
	$query = "BEGIN; SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;". 
					"	SELECT zamek FROM $table WHERE $rowid='$id'";
	$result = pg_query($query);
	db_one_row($result, $pid, $skript, "$typ $id lock conflict error!", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);

	$lock = getInt($row[0]);
	if ($lock != null) {
		if ($lock == $pid) $vrat=true; // je-li to muj zamek
		else $vrat=false;
		
		$query = "COMMIT";
		$result = pg_query($query);
		return $vrat;
	}
	else {
		
		// zamci zdroj a ukoci transakci
		$query = "UPDATE $table SET zamek='$pid', zamek_cas=LOCALTIMESTAMP (0)".
			" WHERE $rowid='$id'; COMMIT";
		$result = pg_query($query);
		return true;
	}

	return false;
}

function is_locked($user, $id, $typ, $skript)
{
	global $LOG_DBE, $NOT_LOCK;
	
	$table = get_lock_table($typ);
	$rowid = get_lock_rowid($typ);

	$query = "SELECT zamek FROM $table WHERE $rowid='$id'";
	$result = pg_query($query);
	db_one_row($result, $user, $skript, "$typ $id unlock conflict error!", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);
	$lock = getInt($row[0]);
	
	return $lock != null ? $lock : $NOT_LOCK;
}

function unlock($pid, $id, $typ, $skript) 
{
	global $LOG_DBE, $NOT_LOCK, $NOT_PERMITTED_UNLOCK, $UNLOCKED, $UNLOCK_ERROR;

	$table = get_lock_table($typ);
	$rowid = get_lock_rowid($typ);

	$query = "BEGIN; SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;".  
					"	SELECT zamek FROM $table WHERE $rowid='$id'";
	$result = pg_query($query);
	db_one_row($result, $pid, $skript, "$typ $id unlock conflict error!", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);
	$lock = getInt($row[0]);
	
	if ($lock == null) return $NOT_LOCK;

	if ($lock != $pid) {
		$query = "COMMIT";
		$result = pg_query($query);
		return $NOT_PERMITTED_UNLOCK;
	}
	else {
		$query = "UPDATE $table SET zamek=NULL, zamek_cas=NULL".
						"	WHERE $rowid='$id'; COMMIT";
		$result = pg_query($query);
		return $UNLOCKED;
	}

	return $UNLOCK_ERROR;
}

function force_unlock($pid, $id, $typ, $skript, $admin)
{
	global $LOG_DBE, $NOT_LOCK, $NOT_PERMITTED_UNLOCK, $UNLOCKED, $UNLOCK_ERROR;

	$table = get_lock_table($typ);
	$rowid = get_lock_rowid($typ);

	$query = "BEGIN; SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;".
					"	SELECT zamek FROM $table WHERE $rowid='$id'";
	$result = pg_query($query);
	db_one_row($result, $pid, $skript, "$typ $id force unlock conflict error!", 
							"cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);
	$lock = getInt($row[0]);
	
	if ($lock == null) return $NOT_LOCK;

	if ($admin || $lock == $pid) {
		$query = "UPDATE $table SET zamek=NULL, zamek_cas=NULL". 
						"	WHERE $rowid='$id'; COMMIT";
		$result = pg_query($query);
		return $UNLOCKED;
	}
	else {
		$query = "COMMIT";
		$result = pg_query($query);
		return $NOT_PERMITTED_UNLOCK;
	}
	return $UNLOCK_ERROR;
}

function get_rights_message($typ) 
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK;

	switch ($typ) {
	case $SOURCE: return "Source";
	case $MAGAZINE: return "Magazine";
	case $NEWS: return "News";
	case $BOOK: return "Book";
	default: return "Source";
	}
}

function get_rights_delete($typ) 
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK,
		$RGHT_DELETE_SOURCE, $RGHT_DELETE_MAGAZINE, $RGHT_DELETE_BOOK,
		$RGHT_DELETE_NEWS;

	switch ($typ) {
	case $SOURCE: return $RGHT_DELETE_SOURCE;
	case $MAGAZINE: return $RGHT_DELETE_MAGAZINE;
	case $NEWS: return $RGHT_DELETE_NEWS;
	case $BOOK: return $RGHT_DELETE_BOOK;
	default: return $RGHT_DELETE_SOURCE;
	}
}

function get_rights_edit($typ)
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK,
		$RGHT_EDIT_SOURCE, $RGHT_EDIT_MAGAZINE, $RGHT_EDIT_BOOK,
		$RGHT_EDIT_NEWS;
	
	switch ($typ) {
	case $SOURCE: return $RGHT_EDIT_SOURCE;
	case $MAGAZINE: return $RGHT_EDIT_MAGAZINE;
	case $NEWS: return $RGHT_EDIT_NEWS;
	case $BOOK: return $RGHT_EDIT_BOOK;
	default: return $RGHT_EDIT_SOURCE;
	}
}


function check_rights_delete($pid, $id, $skript, $typ) 
{
	global $RGHT_DB_FAILED, $RGHT_OK, $RGHT_FAILED, $LOG_DBE,
		$LOC_RIGHT_ERROR, $LOC_ERROR_REL, $LOG_RGH, 
		$SOURCE, $MAGAZINE;

	$table = get_lock_table($typ);
	$label_id = get_lock_rowid($typ); 
	$what = get_rights_message($typ);
	$access = get_rights_delete($typ);

	$query = "SELECT odpovedny_spravce FROM $table WHERE $label_id='$id'";
	
	$result = pg_query($query);
	db_one_row($result, $pid, $skript, "$what $id right conflict error!", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);

	if ($row[0] != $pid) { 
		logit($pid, $_SERVER['PHP_SELF'], "User is not permitted to delete $what='$id'.", 
					$LOG_RGH);	
		print_right_error_page("cs", $access);
	}
	else { return $RGHT_OK;	}
}

function check_rights_edit($pid, $id, $skript, $typ)
{
	global $RGHT_OK, $RGHT_FAILED, $LOC_RIGHT_ERROR, $LOG_RGH, 
					$LOC_ERROR_REL, $SOURCE, $MAGAZINE;
	
	$table = get_lock_table($typ);
	$label_id = get_lock_rowid($typ); 
	$what = get_rights_message($typ);
	$access = get_rights_edit($typ);


	$query = "SELECT odpovedny_spravce FROM $table WHERE $label_id='$id'";
	$result = pg_query($query);
	db_one_row($result, $pid, $skript, "$what $id right conflict error!", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);
	
	if ($row[0] != $pid) {
		logit($pid, $_SERVER['PHP_SELF'], "User is not permitted to edit $what='$id'.", 
					$LOG_RGH);
		print_right_error_page("cs", $access);
	}
	else { return $RGHT_OK; }
}

function check_rights($user, $typ, $action, $id, $skript) 
{

	global $USER_DB_PID_FAILED, $USER_DB_PID_CONFLICT, $LOC_RIGHT_ERROR,
					$RGHT_DB_FAILED, $RGHT_DELETE, $RGHT_ERROR, $RGHT_OK,
					$RGHT_IS_ADMIN, $RGHT_EDIT, $LOC_ERROR_REL, $LOG_RGH,
					$SOURCE, $MAGAZINE;

	$userinfo = getUserInfo($user, $skript);
	
	$pid = getPid($userinfo);
	
	if (getIsAdmin($userinfo)) return $userinfo;

	switch ($action) {
	
	case $RGHT_DELETE: 
		return (check_rights_delete($pid, $id, $skript, $typ) == $RGHT_OK ? 
			$userinfo : $RGHT_ERROR);
		
	case $RGHT_EDIT:
		return (check_rights_edit($pid, $id, $skript, $typ) == $RGHT_OK ? 
			$userinfo : $RGHT_ERROR);
		
	case $RGHT_IS_ADMIN: 
		logit($pid, $_SERVER['PHP_SELF'], 
			"User try to entre non-user area.", $LOG_RGH);
		print_right_error_page("cs", $RGHT_IS_ADMIN);
		break;
	
	default: 
		logit($user,$_SERVER['PHP_SELF'],"Bad request for check right '$action'.", $LOG_ERR);
		print_error_page("cs");
		break;
	}

	return $RGHT_ERROR;
}
