<?php

require_once("config.php");
require_once("constants.php");
require_once("logging.php");
require_once("functions.php");


// pripravit serializaci zapisu do RSS

function getRSSType($type) 
{
	global $SOURCE, $MAGAZINE, $NEWS, $BOOK;
	
	switch ($type) {
	case $SOURCE: return "s";
	case $MAGAZINE: return "m";
	case $NEWS: return "n";
	case $BOOK: return "b";
	default: return"-";
	}
}

function guidType($guid) {
	global $SOURCE, $MAGAZINE, $NEWS;

	$type = $guid[0];

	switch ($type) {
	case 's': return $SOURCE;
	case 'm': return $MAGAZINE;
	case 'n': return $NEWS;
	case 'b': return $BOOK;
	default: return $SOURCE;
	}
}	

function getGuidRawId($guid) {

	return substr($guid, 1);
}

function lockRSS($type) {
	global $RSS_TYPE_CZ, $RSS_TYPE_EN, $RSS_TYPE_DETAIL_CZ, $RSS_TYPE_DETAIL_EN;

	$max_pokus = 10;

	$user = getUser();
	$pid = getPid(getUserInfo($user, "rss.php"));

	$zamceno = true;
	$pokus = 0;
	while ($zamceno && $pokus < $max_pokus) { 
		$query = "BEGIN; SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;".
			" SELECT zamcen FROM rss WHERE id = $type";
		$result = pg_query($query);
		db_one_row($result, $user, "rss.php", "RSS lock error ($type).", "cs");
		$row = pg_fetch_array($result, NULL, PGSQL_NUM);

		if (($zamceno = getBool($row[0]))) {
			$pokus++;
			sleep(rand(1,3));
			$query = "COMMIT";
			$result = pg_query($query);
		}
		else {
			$query = "UPDATE rss SET zamcen = 't', uzivatelem='$pid', cas=CURRENT_TIMESTAMP WHERE id = $type; COMMIT";
			$result = pg_query($query);
			return true;
		}
	}

	return false;
}

function unlockRSS($type) {
	global $NOT_LOCK, $NOT_PERMITTED_UNLOCK, $UNLOCKED;

	$user = getUser();
	$pid = getPid(getUserInfo($user, "rss.php"));

	$query = "BEGIN; SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;".
		" SELECT zamcen, uzivatelem FROM rss WHERE id = $type";

	$result = pg_query($query);
	db_one_row($result, $user, "rss.php", "RSS unlock error ($type).", "cs");
	$row = pg_fetch_array($result, NULL, PGSQL_NUM);

	$lock = getInt($row[1]);

	if ($lock == null) return $NOT_LOCK;

	if ($lock != $pid) {
		$query = "COMMIT";
		$result = pg_query($query);
		return $NOT_PERMITTED_UNLOCK;
	}
	else {
		$query = "UPDATE rss SET zamcen = 'f', uzivatelem=null WHERE id = $type; COMMIT";
		$result = pg_query($query);
		return $UNLOCKED;
	}
}


function RSSAddItem($type, $id, $title, $link, $description, $rss_prefix, $new, $lang, $created)
{
	global $RSS_FILE, $RSS_DETAIL_FILE, $RSS_FILE_EN, $RSS_DETAIL_FILE_EN, 
		$SOURCE, $MAGAZINE, $NEWS, $RSS_FILE_WRITE, $RSS_FILE_WRITE_EN,
		$RSS_DETAIL_FILE_WRITE, $RSS_DETAIL_FILE_WRITE_EN, $LOG_INF, $LOG_WAR,
		$RSS_TYPE_CZ, $RSS_TYPE_EN, $RSS_TYPE_DETAIL_CZ, $RSS_TYPE_DETAIL_EN,
		$NOT_PERMITTED_UNLOCK, $NEW_TIME;

	$doc = new DOMDocument();

	$user = getUser();

	$is_new = $new;

	// zaznam, ktery updatuju a je vytvoren tentyz den, povazuji za novy
	if (! $new && $type != $NEWS && $created != null && 
		compareCurrentDate($created) == 0) {
		$is_new = true;
	}


	$detail = false;
	// neni-li zaznam novy, pak ho dej do kanalu, ktery informuje detailne
	if ($type != $NEWS && ! $is_new) {
		$detail = true;
	}

	if ($lang == "en") {	
		if ($detail) {
			$rss_type =  $RSS_TYPE_DETAIL_EN;
			$toload="../$RSS_DETAIL_FILE_EN";
			$towrite = $RSS_DETAIL_FILE_WRITE_EN;
		}
		else {
			$rss_type = $RSS_TYPE_EN;
			$toload="../$RSS_FILE_EN";
			$towrite = $RSS_FILE_WRITE_EN;
		}
	}
	else {
		if ($detail) {
			$rss_type = $RSS_TYPE_DETAIL_CZ;
			$toload="../$RSS_DETAIL_FILE";
			$towrite = $RSS_DETAIL_FILE_WRITE;
		}
		else {
			$rss_type = $RSS_TYPE_CZ;
			$toload="../$RSS_FILE";
			$towrite = $RSS_FILE_WRITE;
		}
	}

	if (! lockRSS($rss_type)) {
		logit($user, "rss.php", "Cannot lock RSS ($rss_type) for writing record ($id, $type).", $LOG_WAR);
	}
	
	else {

	$doc->load($toload);

	$date = date("r");
	$guid = getRSSType($type).$id;

	$build = $doc->getElementsByTagName("lastBuildDate");
	$build->item(0)->parentNode->
		replaceChild($doc->createElement("lastBuildDate", $date), $build->item(0));
		

	$items = $doc->getElementsByTagName("guid");

	// pokud uz tam feed je, tak ho zrus
	foreach ($items as $item) {
		if ($item->textContent == $guid) {
			$item->parentNode->parentNode->removeChild($item->parentNode);
			break;
		}
	}

		$itemElem = $doc->createElement("item");

		$titleElem = $doc->createElement("title", htmlEscape($title) . $rss_prefix);
		$linkElem = $doc->createElement("link", htmlEscape($link));
		$descElem = $doc->createElement("description", htmlEscape($description));
		$guidElem = $doc->createElement("guid", $guid);
		$guidElem->setAttribute('isPermaLink', 'false');

		$dateElem = $doc->createElement("pubDate", $date);

		$itemElem->appendChild($titleElem);
		$itemElem->appendChild($linkElem);
		$itemElem->appendChild($descElem);
		$itemElem->appendChild($guidElem);
		$itemElem->appendChild($dateElem);

	$channels = $doc->getElementsByTagName("channel");

	$firstChannelElem = $channels->item(0);

	$items = $doc->getElementsByTagName("item");

	if ($items == null) {
		$firstChannelElem->appendChild($itemElem);
	}
	else {
		$firstItemElem = $items->item(0);

		$firstChannelElem->insertBefore($itemElem, $firstItemElem);
	}

	$doc->save($towrite);

	if (unlockRSS($rss_type) == $NOT_PERMITTED_UNLOCK) {
		logit($user, "rss.php", "User $user is not allowed to unlock rss $rss_type", $LOG_WAR);
	}

	}

	// je-li zdroj novy, musi byt v obou kanalech 
	// veskere nove veci zapisuji primo do hlavniho kanalu
	// ale novy zdroj musi byt i v podrobnem, takze ho tam take zapiseme
	if ($is_new && $type != $NEWS) {
		RSSAddItem($type, $id, $title, $link, $description, $rss_prefix, false, $lang, null);
	}

}


function RSSRemove($doc, $id) 
{
	$items = $doc->getElementsByTagName("guid");

	// pokud uz tam feed je, tak ho zrus
	foreach ($items as $item) {
		if ($item->textContent == $id) {
			$item->parentNode->parentNode->removeChild($item->parentNode);
			return true;
		}
	}

	return false;
}


// pri mazani zdroje ci aktuality 
// neni nutne updatovat zaznam v databazi
function RSSDelItem($type, $id) 
{
	global $RSS_FILE, $RSS_DETAIL_FILE, $RSS_FILE_EN, $RSS_DETAIL_FILE_EN, 
		$SOURCE, $MAGAZINE, $NEWS, $RSS_FILE_WRITE, $RSS_FILE_WRITE_EN,
		$RSS_DETAIL_FILE_WRITE, $RSS_DETAIL_FILE_WRITE_EN,
		$RSS_TYPE_CZ, $RSS_TYPE_EN, $RSS_TYPE_DETAIL_CZ, $RSS_TYPE_DETAIL_EN,
	  $NOT_PERMITTED_UNLOCK, $LOG_WAR;


	$id = getRSSType($type).$id;
	$doc = new DOMDocument();

	if (! lockRSS($RSS_TYPE_CZ)) {
		logit($user, "rss.php", "Cannot lock RSS ($RSS_TYPE_CZ) for writing! Source ($id, $type).", $LOG_WAR);
	}
	else {

		$doc->load("../$RSS_FILE");
		if (RSSRemove($doc, $id)) $doc->save("$RSS_FILE_WRITE");
		
		if (unlockRSS($RSS_TYPE_CZ) == $NOT_PERMITTED_UNLOCK) {
			logit($user, "rss.php", "User $user is not allowed to unlock rss $rss_type", $LOG_WAR);
		}

	}
	
	if (! lockRSS($RSS_TYPE_EN)) {
		logit($user, "rss.php", "Cannot lock RSS ($RSS_TYPE_EN) for writing! Source ($id, $type).", $LOG_WAR);
	}
	else {

		$doc->load("../$RSS_FILE_EN");
		if (RSSRemove($doc, $id)) $doc->save("$RSS_FILE_WRITE_EN");
		
		if (unlockRSS($RSS_TYPE_EN) == $NOT_PERMITTED_UNLOCK) {
			logit($user, "rss.php", "User $user is not allowed to unlock rss $rss_type", $LOG_WAR);
		}

	}
	
	if (! lockRSS($RSS_TYPE_DETAIL_CZ)) {
		logit($user, "rss.php", "Cannot lock RSS ($RSS_TYPE_DETAIL_CZ) for writing! Source ($id, $type).", $LOG_WAR);
	}
	else {

		$doc->load("../$RSS_DETAIL_FILE");
		if (RSSRemove($doc, $id)) $doc->save("$RSS_DETAIL_FILE_WRITE");
		
		if (unlockRSS($RSS_TYPE_DETAIL_CZ) == $NOT_PERMITTED_UNLOCK) {
			logit($user, "rss.php", "User $user is not allowed to unlock rss $rss_type", $LOG_WAR);
		}

	}

	if (! lockRSS($RSS_TYPE_DETAIL_EN)) {
		logit($user, "rss.php", "Cannot lock RSS ($RSS_TYPE_DETAIL_EN) for writing! Source ($id, $type).", $LOG_WAR);
	}
	else {

		$doc->load("../$RSS_DETAIL_FILE_EN");
		if (RSSRemove($doc, $id)) $doc->save("$RSS_DETAIL_FILE_WRITE_EN");
		
		if (unlockRSS($RSS_TYPE_DETAIL_EN) == $NOT_PERMITTED_UNLOCK) {
			logit($user, "rss.php", "User $user is not allowed to unlock rss $rss_type", $LOG_WAR);
		}

	}
}

function RSSDelItemRaw($guid, $lang) {

	global $RSS_FILE, $RSS_FILE_EN, $RSS_FILE_WRITE, $RSS_FILE_WRITE_EN;



	if ($lang == 'en') $rss_file = $RSS_FILE_WRITE_EN;
	else $rss_file = $RSS_FILE_WRITE;

	$doc = new DOMDocument();
	$doc->load($rss_file);

	$items = $doc->getElementsByTagName("guid");

	foreach ($items as $item) {
		if ($item->textContent == $guid) {
			$item->parentNode->parentNode->removeChild($item->parentNode);
			break;
		}
	}

	$doc->save($rss_file);
}

?>
