<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text" encoding="utf-8" indent="no" 
	omit-xml-declaration="yes" />

<xsl:template match="/esources_IPs">
## This is automatically generated EZproxy config file. (Source is 
## http://library.muni.cz/ezdroje/ips.xml).

## Vlastimil Krejcir, krejcir@ics.muni.cz
## ICS MU 2009


Name ezproxy.muni.cz
Interface 147.251.6.77
LoginPort 80
Option ProxyByHostname


## Hardcoded databases

Title American Chemical Society
URL http://pubs.acs.org
DJ acs.org
Find hostdev="pubsdev.acs.org"
Replace hostdev="^ppubsdev.acs.org^"
Find hosttest="pubstest.acs.org"
Replace hosttest="^ppubstest.acs.org^"
Find hostprod="pubs.acs.org"
Replace hostprod="^ppubs.acs.org^"


Title BioOne
URL http://www.bioone.org/
Domain bioone.org
Host 65.245.134.215


Title EBSCOhost
URL http://search.ebscohost.com/login.aspx
DJ ebscohost.com
Host search.epnet.com
DJ epnet.com
Host openurl.ebscohost.com
Host web.ebscohost.com
Find proxy.cfm?url=http://
Replace proxy.cfm?url=http://^A
Find /login?url=http://
Replace /login?url=http://^A

Option DomainCookieOnly
Title IEEE Xplore
URL http://ieeexplore.ieee.org/lpdocs/epic03/
Domain ieee.org
Option Cookie


Title ISI Proceedings
URL http://isiknowledge.com
Domain isiknowledge.com
Host www.isiknowledge.com
Host admin.isiknowledge.com
Host apps.isiknowledge.com
Host portal.isiknowledge.com
Host pcs.isiknowledge.com
Host rss.isiknowledge.com
Host toc.isiknowledge.com
Host images.isiknowledge.com
Host estipub.isiknowledge.com
Host links.isiknowledge.com
Host gateway.isiknowledge.com
Host cds02.isiknowledge.com
Host cds15.isiknowledge.com
Host cds22.isiknowledge.com
Host cds23.isiknowledge.com
Host cds1.isiknowledge.com
Host jcr.isiknowledge.com
Host esi.isiknowledge.com
Host hcr3.isiknowledge.com
Host www.isihighlycited.com
Host tsi15.isiknowledge.com
Host tsi17.isiknowledge.com
Host tsi1.isiknowledge.com
Host tsi.isiknowledge.com
Host charts.isiknowledge.com
Host lca.isiknowledge.com
Host www.myendnoteweb.com
Host newisiknowledge.com
Host www.newisiknowledge.com
Host pcs.newisiknowledge.com
Host newface.newisiknowledge.com
Host apps.newisiknowledge.com
Host images.newisiknowledge.com
Host links.newisiknowledge.com
Host gateway.newisiknowledge.com
Host toc.newisiknowledge.com
Host admin-apps.isiknowledge.com
Host admin-router.isiknowledge.com
Host pcs.isiknowledge.com

Option DomainCookieOnly
Title JSTOR
URL http://www.jstor.org
Domain jstor.org
Option Cookie


Title Ovid
URL http://ovidsp.ovid.com/autologin.html
Host gateway.ovid.com
DJ ovid.com


Title Kluwer Online (Kluwer Academic Publishers)
URL http://www.kluweronline.com
DJ kluweronline.com
DJ wkap.nl
DJ lwwonline.com
Find document.domain="lwwonline.com"
Replace document.domain="lwwonline.com.^h"
Find domain=.lwwonline.com
Replace domain=.lwwonline.com.^h
Find document.domain = ".kluweronline.com"
Replace document.domain = ".kluweronline.com.^h"
Find document.domain = "kluweronline.com"
Replace document.domain = "kluweronline.com.^h"
Find domain=.kluweronline.com
Replace domain=.kluweronline.com.^h
Find document.domain="kluweronline.com"
Replace document.domain="kluweronline.com.^h"
Find document.domain = thisDomain
Replace document.domain = "kluweronline.com.^h";


Option DomainCookieOnly
Title ProQuest
URL http://proquest.umi.com/login/ipauto
DJ proquest.com
DJ umi.com
Find ExpressImport.asp?vendor=ProQuest&amp;url=http://
Replace ExpressImport.asp?vendor=ProQuest&amp;url=http://^A
Option Cookie


Title PubMed
URL http://www.ncbi.nlm.nih.gov/sites/entrez?db=PubMed
DJ nih.gov
# dx.doi.org provides linking Nature, Springer, Wiley, and others
DJ dx.doi.org
# linkinghub.elsevier.com provides linking to Elsevier and ScienceDirect
DJ linkinghub.elsevier.com
Find &amp;url=http://
Replace &amp;url=http://^A
Find &amp;amp;url=http://
Replace &amp;amp;url=http://^A
Find fref.fcgi?http://
Replace fref.fcgi?http://^A
Find 'https://' + window.location.hostname
Replace 'https://^swww.ncbi.nlm.nih.gov^'
Find 'https://' + window.location.host +
Replace 'https://^swww.ncbi.nlm.nih.gov^' +

Cookie BROWSER_SUPPORTS_COOKIES=1; domain=.sciencedirect.com
Option DomainCookieOnly
Title ScienceDirect
URL http://www.sciencedirect.com/
DJ sciencedirect.com
HJ linkinghub.elsevier.com
HJ cs.sciencedirect.com
Find value="http://
Replace value="http://^A
Option Cookie


Title Scopus
URL http://www.scopus.com/scopus/home.url
DJ scopus.com


Title SpringerLink
URL http://link.springer-ny.com/link/sub_list
HJ www.link.springer-ny.com
HJ www.springerlink.com
DJ springerlink.com
DJ springer-ny.com
DJ springer.de
DJ metapress.com


<xsl:apply-templates select="esource" />

<xsl:text>


</xsl:text>

</xsl:template>

<xsl:template match="esource">

<xsl:variable name="name" select="name" />

<xsl:choose>
	<xsl:when test="starts-with($name, '*')" />
	
	<xsl:when test="contains($name, 'EBSCO')" /> <!-- hardcoded -->
	
	<xsl:when test="contains($name, 'ACS')" /> <!-- hardcoded -->
	
	<xsl:when test="contains($name, 'BioOne')" /> <!-- hardcoded -->
	
	<xsl:when test="contains($name, 'Xplore')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'ISI')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'JSTOR')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'Kluwer Law')" /> <!-- hardcoded -->



	<xsl:when test="contains($name, 'Oxford')">
		<!-- 
		will be downloaded from 
		http://www.oxfordjournals.org/help/techinfo/ezproxyconfig.txt
		-->
	</xsl:when>

	<xsl:when test="contains($name, 'ProQuest')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'Pubmed')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'ScienceDirect')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'SCOPUS')" /> <!-- hardcoded -->

	<xsl:when test="contains($name, 'SpringerLINK')" /> <!-- hardcoded -->
	

	<xsl:otherwise>

Title <xsl:value-of select="name" />
URL <xsl:value-of select="url" />
<xsl:apply-templates select="aliases" />
Domain <xsl:value-of select="domain_name" />

	</xsl:otherwise>
</xsl:choose>

</xsl:template>

<xsl:template match="aliases">
<xsl:for-each select="alias">
Host <xsl:value-of select="." />
</xsl:for-each>
</xsl:template>

</xsl:stylesheet>

