<?php

require_once("eizlibs/db_connect.php");
require_once("eizlibs/functions.php");
require_once("eizlibs/rights.php");
require_once("lib/options_class.php");

$VERSION='0.1';
$SCRIPT='check_books_updates.php';

$singleoptions = array(
	'help' => option::newopt('h', 'help', 'vypise tuto napovedu'),
	'version' => option::newopt('V', 'version', 'vypise verzi skriptu'),
	'verbose' => option::newopt('v', 'verbose', 'podrobnejsi vypis provadenych operaci'),
	'justshow' => option::newopt('j', 'just-show', 'jen ukaze provade akce'),
	'emails' => option::newopt('e:', 'emails:', '', '<email1>[,<email2>, ...]')
);

$myoptions = options::getOptions($singleoptions);

if ($argc == 1 || $myoptions->isOpt($singleoptions['help'])) {
	echo "$SCRIPT (Portal EIZ)\n";
	echo "Verze: $VERSION\n";
	echo "Skript provede kontrolu zmen v knihach (zmena statutu apod.) a o nalezenych\n";
	echo "zmenach informuje uzivatele na zadanych emailovych adresach.\n";
	echo "Pouziti: php $SCRIPT [-jhvV] -e <email1>[,<email2>, ...]\n";
	echo "Volby:\n";

	$myoptions->optionsHelp();

	exit(0);
}

if ($myoptions->isOpt($singleoptions['version'])) {
	echo "$SCRIPT, verze $VERSION\n";
	exit(0);
}

$verbose = $myoptions->isOpt($singleoptions['verbose']);

$justshow = $myoptions->isOpt($singleoptions['justshow']);

$optemails = $myoptions->isOpt($singleoptions['emails']);

$emails = array();
if ($optemails != '') {
	$emails = explode(",", $optemails);
}
else {
	fwrite(STDERR, "Musite vlozit alespon jeden email.\n");
	exit(1);
}

if ($verbose) {
	echo "Mail bude zaslan na adresy:\n";
	foreach($emails as $email) {
		echo "$email\n";
	}
	echo "Kontroluji se zmeny v knihach...\n";
}

connect_db();

date_default_timezone_set($DEFAULT_TIME_ZONE);
$DATE_STRING = 'Y-m-d-h:i:s'; 

$cdate = getDate();
$logdate = $cdate['year']."-".$cdate['mon']."-".$cdate['mday'];

/* nyni zpracujeme zmeny v casopisech a poslu si email s upozornenim */
$query = "SELECT kniha_id, titul, odpovedny_spravce, modifikace".
          " FROM knihy ORDER BY odpovedny_spravce, titul";
$result = pg_query($query);
if (! $result) die("ERROR read knihy - ".pg_last_error());

$zmenene = "";

while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

    $c = $row['modifikace'];
    $modified_time = mktime(getHour($c), getMinute($c), getSecond($c),
                          getMonth($c), getDay($c), getYear($c));
    $local_time = explode(" ", microtime());

    // pokud doslo k modifikaci v poslednich 24 hodinach
    if (($local_time[1] - $modified_time) < 86400) {
      $id = $row['kniha_id'];
      $titul = $row['titul'];
      $spravce = $row['odpovedny_spravce'];

      $zmenene .= "$id ($titul) [$spravce] - $c\n";
    }
}




if ($zmenene != "") {

	if ($verbose) {
		echo "Informace o zmenach budou odeslany na uveden mailove adresy.\n";
		echo "Zmeny v knihach:\n";
		echo $zmenene;
	}

	$hlavicka = "From: $NOREPLY_MAIL\r\n".
		"Reply-To: $NOREPLY_MAIL\r\n".
		"MIME-Version: 1.0\r\n".
		"Content-Type: text/plain; charset=utf-8\r\n".
		"Content-Disposition: inline\r\n".
		"Content-Transfer-Encoding: 8bit\r\n";

	if ($justshow) {
		echo $hlavicka;
		echo "\r\n";
		echo "\n";
		echo $zmenene;
		echo "\n";
	}
	else {
		foreach($emails as $email) {
			$send = mail($email, "Zmeny v knihach - $logdate",
    		$zmenene, $hlavicka, $ADD_EMAIL_PARAMS);
  		if (! $send) { echo "$logdate ERROR sending mail\n"; break; }
  		else { echo "$logdate SENT - mail was sent to $email\n"; }
		}
	}
}
else {
	if ($verbose) {
		echo "nebyly zjisteny zadne zmeny.\n";
	}
}

echo "$logdate CHECKED - changes in books checked\n";

?>
