<?php

require_once("eizlibs/db_connect.php");
require_once("eizlibs/functions.php");
require_once("eizlibs/rights.php");
require_once("lib/options_class.php");

$VERSION='0.4';
$SCRIPT='check_expir.php';

$singleoptions = array(
	'help' => option::newopt('h', 'help', 'vypise tuto napovedu'),
	'version' => option::newopt('V', 'version', 'vypise verzi skriptu'),
	'verbose' => option::newopt('v', 'verbose', 'podrobnejsi vypis provadenych operaci'),
	'justshow' => option::newopt('j', 'just-show', 'jen ukaze provade akce'),
	'sourcesonly' => option::newopt('s', 'sources-only', 'kontroluj jen zdroje'),
	'additionalemails' => option::newopt('a:', 'additional-emails:', 'dodatecne e-mailove adresy', '<adresa1>[,<adresa2>, ...]')
);

$myoptions = options::getOptions($singleoptions);

if ($argc == 1 || $myoptions->isOpt($singleoptions['help'])) {
	echo "$SCRIPT (Portal EIZ)\n";
	echo "Verze: $VERSION\n";
	echo "Skript provede kontrolu expirace vsech zdroju a casopisu, vyprsela-li doba\n";
	echo "dostupnosti, pak zasle e-mailem upozorneni spravci zdroje a pripadne na\n";
	echo "adresy uvedene v --additional-emails\n";
	echo "Pouziti: php $SCRIPT [-hjsvV] -a <adresa1>[,<adresa2>, ...]\n";
	echo "Volby:\n";

	$myoptions->optionsHelp();

	exit(0);
}

if ($myoptions->isOpt($singleoptions['version'])) {
	echo "$SCRIPT, verze $VERSION\n";
	exit(0);
}

$verbose = $myoptions->isOpt($singleoptions['verbose']);

$justshow = $myoptions->isOpt($singleoptions['justshow']);

$sourcesonly = $myoptions->isOpt($singleoptions['sourcesonly']);

$additionalemails = $myoptions->isOpt($singleoptions['additionalemails']);

$emails = array();
if ($additionalemails != '') {
	$emails = explode(",", $additionalemails);
}

if ($verbose) {
	echo "Vysledky kontroly budou zasilany i na nasledujici adresy:\n";

	foreach($emails as $email) {
		echo "$email\n";
	}
}

date_default_timezone_set($DEFAULT_TIME_ZONE);
$DATE_STRING = 'Y-m-d-h:i:s'; 


connect_db();

$hlavicka = "From: $NOREPLY_MAIL\r\n".
						"Reply-To: $NOREPLY_MAIL\r\n".
						"MIME-Version: 1.0\r\n".
						"Content-Type: text/plain; charset=utf-8\r\n".
						"Content-Disposition: inline\r\n".
						"Content-Transfer-Encoding: 8bit\r\n";

$cdate = getDate();
$logdate = $cdate['year']."-".$cdate['mon']."-".$cdate['mday'];
$cdate = $cdate['mday'].".".$cdate['mon'].".".$cdate['year'];

$subject = "=?UTF-8?B?".base64_encode("Zpráva Portálu EIZ - expirované zdroje")."?=";

$uvod = 
"Toto je automaticky generovaná zpráva Portálu EIZ. Neodpovídejte na ni prosím."
."\nPro získání dalších informací můžete kontaktovat správce na adrese\n$ADMIN_MAIL.\n\n".
"Následujícím zdrojům, časopisům a knihám, které spravujete, vypršela platnost:\n";

$query = "SELECT zdroj_id, zkratka, expirace, odpovedny_spravce FROM zdroje
	WHERE expirace < CURRENT_DATE AND kontrola_expirace='f' AND aktivni='t'
	AND povoleny='t'";

$result = pg_query($query);

if (! $result) die("ERROR read - ".pg_last_error());

$expirovane = array();

while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) 
{
	$name = $row['zkratka'];
	$id = $row['zdroj_id'];
	$pid = $row['odpovedny_spravce'];
	$expirace = getDay($row['expirace']).".".getMonth($row['expirace']).".".getYear($row['expirace']);
	if (! isset($expirovane[$pid])) 
		$expirovane[$pid] = "$name ($MY_SURL/$AUTH_DIR/zdroj.php?id=$id)\n";
	else 
		$expirovane[$pid] .= "$name ($MY_SURL/$AUTH_DIR/zdroj.php?id=$id)\n";

	if (! $justshow) {
		$query = "UPDATE zdroje SET kontrola_expirace='t' WHERE zdroj_id=$id";
		$result_up = pg_query($query);
		if (! $result_up) die("ERROR update - ".pg_last_error());
	}
}

/* expirace u casopisu */
if (! $sourcesonly) {
	$query = "SELECT casopis_id, titul, expirace, odpovedny_spravce 
		FROM casopisy
		WHERE expirace < CURRENT_DATE AND 
		kontrola_expirace='f' AND aktivni='t'";

	$result = pg_query($query);

	if (! $result) die("ERROR read - ".pg_last_error());

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC))
	{
		$name = $row['titul'];
		$id = $row['casopis_id'];
		$pid = $row['odpovedny_spravce'];
		$expirace = getDay($row['expirace']).".".getMonth($row['expirace']).".".getYear($row['expirace']);
		if (! isset($expirovane[$pid])) 
			$expirovane[$pid] = "$name ($MY_SURL/$AUTH_DIR/casopis.php?id=$id)\n";
		else 
			$expirovane[$pid] .= "$name ($MY_SURL/$AUTH_DIR/casopis.php?id=$id)\n";

		if (! $justshow) {
			$query = "UPDATE casopisy SET kontrola_expirace='t' WHERE casopis_id=$id";
			$result_up = pg_query($query);
			if (! $result_up) die("ERROR update - ".pg_last_error());
		}
	}


	$query = "SELECT kniha_id, titul, expirace, odpovedny_spravce 
		FROM knihy
		WHERE expirace < CURRENT_DATE AND 
		kontrola_expirace='f' AND aktivni='t'";

	$result = pg_query($query);

	if (! $result) die("ERROR read - ".pg_last_error());

	while($row = pg_fetch_array($result, NULL, PGSQL_ASSOC))
	{
		$name = $row['titul'];
		$id = $row['kniha_id'];
		$pid = $row['odpovedny_spravce'];
		$expirace = getDay($row['expirace']).".".getMonth($row['expirace']).".".getYear($row['expirace']);
		if (! isset($expirovane[$pid])) 
			$expirovane[$pid] = "$name ($MY_SURL/$AUTH_DIR/kniha.php?id=$id)\n";
		else 
			$expirovane[$pid] .= "$name ($MY_SURL/$AUTH_DIR/kniha.php?id=$id)\n";

		if (! $justshow) {
			$query = "UPDATE knihy SET kontrola_expirace='t' WHERE kniha_id=$id";
			$result_up = pg_query($query);
			if (! $result_up) die("ERROR update - ".pg_last_error());
		}
	}

}


foreach($expirovane as $pid => $message) {

	$query = "SELECT email FROM spravci WHERE pid='$pid'";
	
	$result = pg_query($query);
	if (! $result) die("ERROR read - ".pg_last_error());

	$row = pg_fetch_array($result, NULL, PGSQL_ASSOC);
	$email = $row['email'];

	if ($justshow) {
		echo $hlavicka;
		echo "Subject: $subject\r\n";
		echo "To: $email\r\n";
		echo "\r\n";
		echo $uvod;
		echo "\n";
		echo $message;
		echo "\n";
	}

	else {
		//echo "DEBUG: sent $email";
		$send = mail($email, $subject, $uvod.$message, $hlavicka, 
			$ADD_EMAIL_PARAMS);
		if (! $send) { echo "$logdate ERROR sending mail\n"; break; }
		else { echo "$logdate SENT - mail was sent to $email\n"; }
	}

	foreach($emails as $email) {
		if ($justshow) {
			echo "Send to $email\n";
		}
		else {
			//echo "DEBUG: sent $email";
			$send = mail($email, $subject, $uvod.$message, $hlavicka, 
				$ADD_EMAIL_PARAMS);
			if (! $send) { echo "$logdate ERROR sending mail\n"; break; }
		}
	}
}

echo "$logdate CHECKED - all expiration of resources and journals were checked\n";

?>
