<?php

require_once("eizlibs/db_connect.php");
require_once("eizlibs/functions.php");
require_once("eizlibs/rights.php");
require_once("lib/options_class.php");

$VERSION='0.2';
$SCRIPT='check_locks.php';

$singleoptions = array(
	'help' => option::newopt('h', 'help', 'vypise tuto napovedu'),
	'version' => option::newopt('V', 'version', 'vypise verzi skriptu'),
	'verbose' => option::newopt('v', 'verbose', 'podrobnejsi vypis provadenych operaci'),
	'adminid' => option::newopt('i:', 'admin-id:', 'ID uzivatele, ktery provadi odemceni', '<admin_id>')
);

$myoptions = options::getOptions($singleoptions);

if ($argc == 1 || $myoptions->isOpt($singleoptions['help'])) {
	echo "$SCRIPT (Portal EIZ)\n";
	echo "Verze: $VERSION\n";
	echo "Skript provede kontrolu zamku, u objektu zamcenych dele nez 24 hodin provede\n";
	echo "automaticke odemceni. Skript vyzaduje jako parametr ID administratora, ktery\n";
	echo "je opravnen nasilne odemknou objekt - typicky spravce Portalu EIZ (ve vypisu\n";
	echo "uzivatelu v auth/ casti portalu je to uzivatel s cervenou ikonou).\n";
	echo "Pouziti: php $SCRIPT [-hvV] -i <admin-id>\n";
	echo "Volby:\n";

	$myoptions->optionsHelp();

	exit(0);
}

if ($myoptions->isOpt($singleoptions['version'])) {
	echo "$SCRIPT, verze $VERSION\n";
	exit(0);
}

$verbose = $myoptions->isOpt($singleoptions['verbose']);

if (! ($mypid = $myoptions->isOpt($singleoptions['adminid']))) {
	fwrite(STDERR, "Musite vlozit ID spravce portalu (viz --help).\n");
	exit(1);
}

connect_db();

$query = "SELECT pid FROM spravci WHERE pid = '$mypid'";
$result = pg_query($query);
if (! $result || pg_num_rows($result) != 1) die("ERROR read pid ($mypid) from spravci ".pg_last_error());

if ($verbose) {
	echo "Spravce (id = $mypid) byl nalezen.\n";
	echo "Kontroluji se zamky zdroju...\n";
}

date_default_timezone_set($DEFAULT_TIME_ZONE);
$DATE_STRING = 'Y-m-d-h:i:s'; 

$cdate = getDate();
$logdate = $cdate['year']."-".$cdate['mon']."-".$cdate['mday'];


$query = "SELECT zamek, zamek_cas, zdroj_id".
					" FROM zdroje WHERE zamek IS NOT NULL";
$result = pg_query($query);
if (! $result) die("ERROR read zamky(zdroje) - ".pg_last_error());

if (pg_num_rows($result) > 0) {

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {


		$c = $row['zamek_cas'];
		$locked_time = mktime(getHour($c), getMinute($c), getSecond($c), 
													getMonth($c), getDay($c), getYear($c));
		$local_time = explode(" ", microtime());

		if (($local_time[1] - $locked_time) > 86400) {
			$id = $row['zdroj_id'];
			$zamcel = $row['zamek'];
			force_unlock($mypid, $id, $SOURCE, "check_locks.php", true);
			echo "$logdate Unlocking source $id ($c, locked by $zamcel).\n";
		}
	}
}

if ($verbose) {
	echo "Zamky zdroju zkontrolovany.\n";
	echo "Kontroluji se zamky casopisu...\n";
}

$query = "SELECT zamek, zamek_cas, casopis_id".
					" FROM casopisy WHERE zamek IS NOT NULL";
$result = pg_query($query);
if (! $result) die("ERROR read zamky(casopisy) - ".pg_last_error());

if (pg_num_rows($result) > 0) {

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {


		$c = $row['zamek_cas'];
		$locked_time = mktime(getHour($c), getMinute($c), getSecond($c), 
													getMonth($c), getDay($c), getYear($c));
		$local_time = explode(" ", microtime());

		if (($local_time[1] - $locked_time) > 86400) {
			$id = $row['casopis_id'];
			$zamcel = $row['zamek'];
			force_unlock($mypid, $id, $JOURNAL, "check_locks.php", true);
			echo "$logdate Unlocking journals $id ($c, locked by $zamcel).\n";
		}
	}
}

if ($verbose) {
	echo "Zamky casopisu zkontrolovany.\n";
	echo "Kontroluji se zamky knih...\n";
}

$query = "SELECT zamek, zamek_cas, kniha_id".
					" FROM knihy WHERE zamek IS NOT NULL";
$result = pg_query($query);
if (! $result) die("ERROR read zamky(knihy) - ".pg_last_error());

if (pg_num_rows($result) > 0) {

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {


		$c = $row['zamek_cas'];
		$locked_time = mktime(getHour($c), getMinute($c), getSecond($c), 
													getMonth($c), getDay($c), getYear($c));
		$local_time = explode(" ", microtime());

		if (($local_time[1] - $locked_time) > 86400) {
			$id = $row['casopis_id'];
			$zamcel = $row['zamek'];
			force_unlock($mypid, $id, $BOOK, "check_locks.php", true);
			echo "$logdate Unlocking book $id ($c, locked by $zamcel).\n";
		}
	}
}

if ($verbose) {
	echo "Zamky knih zkontrolovany.\n";
	echo "Kontroluji se zamky kanalu RSS...\n";
}

$query = "SELECT id, zamcen, cas, uzivatelem".
					" FROM rss WHERE zamcen = 't'";
$result = pg_query($query);
if (! $result) die("ERROR read zamky(rss) - ".pg_last_error());

if (pg_num_rows($result) > 0) {

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {


		$c = $row['cas'];
		$locked_time = mktime(getHour($c), getMinute($c), getSecond($c), 
													getMonth($c), getDay($c), getYear($c));
		$local_time = explode(" ", microtime());

		if (($local_time[1] - $locked_time) > 21600) {
			$id = $row['id'];
			$zamcel = $row['uzivatelem'];
			$query = "UPDATE rss SET zamcen = 'f', uzivatelem=null WHERE id = $id"; 
			$loc_result = pg_query($query);
			if (! $loc_result) die("ERROR update rss table (unlocking) - ".pg_last_error());
			echo "$logdate Unlocking rss $id ($c, locked by $zamcel).\n";
		}
	}
}

if ($verbose) {
	echo "Zamky kanalu RSS zkontrolovany.\n";
	echo "Kontroluji se zamky souboru...\n";
}

$query = "SELECT soubor_id, zamek, zamek_cas".
					" FROM soubory WHERE zamek IS NOT NULL";
$result = pg_query($query);
if (! $result) die("ERROR read zamky(soubory) - ".pg_last_error());

if (pg_num_rows($result) > 0) {

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {


		$c = $row['zamek_cas'];
		$locked_time = mktime(getHour($c), getMinute($c), getSecond($c), 
													getMonth($c), getDay($c), getYear($c));
		$local_time = explode(" ", microtime());

		if (($local_time[1] - $locked_time) > 86400) {
			$id = $row['soubor_id'];
			$zamcel = $row['zamek'];
			force_unlock($mypid, $id, $FILE, "check_locks.php", true);
			echo "$logdate Unlocking file $id ($c, locked by $zamcel).\n";
		}
	}
}

if ($verbose) {
	echo "Zamky kanalu RSS zkontrolovany.\n";
}

echo "$logdate CHECKED - locks were checked\n";

?>
