<?php

require_once("eizlibs/db_connect.php");
require_once("eizlibs/functions.php");
require_once("lib/options_class.php");

$VERSION='0.2';
$SCRIPT='export_sources.php';

$singleoptions = array(
	'help' => option::newopt('h', 'help', 'vypise tuto napovedu'),
	'version' => option::newopt('V', 'version', 'vypise verzi skriptu'),
	'verbose' => option::newopt('v', 'verbose', 'podrobnejsi vypis provadenych operaci'),
	'sourcesfile' => option::newopt('f:', 'sources-file:', 'XML soubor s adresami pro zpracovani', '<sources.xml>')
);

$myoptions = options::getOptions($singleoptions);

if ($argc == 1 || $myoptions->isOpt($singleoptions['help'])) {
	echo "$SCRIPT (Portal EIZ)\n";
	echo "Verze: $VERSION\n";
	echo "Provadi export vsech aktivnich a povolenych zdroju do zadaneho souboru XML.\n";
	echo "Export je provaden aktualizaci XML souboru, ktery je nacten a podle aktualniho \nstavu databaze je aktualizovan.\n";
	echo "Pred prvnim spustenim je nutne zalozit tento soubor novy dle vzoroveho souboru \n'export_sources-template.xml'.\n";
	echo "Pouziti: php $SCRIPT [-hvV] -f <sources.xml>\n";
	echo "Volby:\n";

	$myoptions->optionsHelp();

	exit(0);
}

if ($myoptions->isOpt($singleoptions['version'])) {
	echo "$SCRIPT, verze $VERSION\n";
	exit(0);
}

$verbose = $myoptions->isOpt($singleoptions['verbose']);

if (! ($xmlfile = $myoptions->isOpt($singleoptions['sourcesfile']))) {
	fwrite(STDERR, "Musite vlozit cestu k souboru XML! (Viz --help).\n");
	exit(1);
}

//echo "\n$xmlfile\n";

date_default_timezone_set($DEFAULT_TIME_ZONE);
$DATE_STRING = 'Y-m-d-h:i:s'; 

$doc = new DOMDocument();

$doc->load($xmlfile);

$root = $doc->documentElement; 

$xpath = new DOMXPath($doc);

function inIP($ips, $ip) {
	
	foreach($ips as $ar_ip) {
		if (trim($ip) == $ar_ip) return true;
	}	

	return false;
}

function inRealNames($realnames, $realname, $domName) {

	if (stripos($domName, $realname) === false) {
		foreach($realnames as $name) {
			if (trim($name) == trim($realname)) return true;
		}
		return false;
	}

	return true;
}

function inAliases($aliases, $alias) {
	foreach($aliases as $la) {
		if (trim($la) == trim($alias)) return true;
	}
	return false;
}

function getIPs($domName, &$ips, &$realnames, &$aliases, &$realchange, 
	&$aliaschange) {

	global $verbose;

	$changed = false;
	if ($verbose) echo "host $domName\n";
	exec("host $domName", $addrs);

	foreach($addrs as $addr) {

		if (preg_match('/has address/i', $addr) > 0) { 
			$ip = preg_replace("/^[^ ]* has address /", '', $addr);

			if (! inIP($ips, $ip)) { array_push($ips, trim($ip)); $changed = true; }	

			$realname = preg_replace("/ has address.*$/i", '', $addr);

			if (! inRealnames($realnames, $realname, $domName)) {
				array_push($realnames, $realname);
				$realchange = true;
			}

		}
	}

	foreach($addrs as $addr) {
		if (preg_match('/is an alias for/i', $addr) > 0) {
			
			$alias = preg_replace("/^[^ ]* is an alias for /", '', $addr);
			$alias = substr($alias, 0, strlen($alias)-1);

			//echo "alias '$alias' - '$domName'\n";
			//foreach ($realnames as $realname) echo "\t '$realname'";
			if (! inRealNames($realnames, $alias, $domName) 
				&& ! inAliases($aliases, $alias)) {
					array_push($aliases, $alias);
					$aliaschange = true;
				}
		}
	}


	return $changed;	
}


function getDomName($url) {
	$domName = preg_replace('!http.?://([^/]*).*!', '$1', $url);
	return preg_replace('/:[0-9]*/', '', $domName);
}

function getTopDomain($url) {
	$casti = explode('.', $url);
	$count = count($casti);
	if ($count > 2) return $casti[$count-2].'.'.$casti[$count-1];

	return $url;
}

function storeIPs($doc, $zdrojNode, $ips, $realnames, $aliases, $churl) {

	// vymaz stare uzly, jsou-li tam
	$childs = $zdrojNode->childNodes;

	$toremove = array();

	for ($i = 0; $i<$childs->length; $i++) {
		$node = $childs->item($i);
		$nodeName = $childs->item($i)->nodeName;

		if ($nodeName == 'IPs' 
			|| $nodeName == 'realnames' 
			|| $nodeName == 'aliases'
			|| $nodeName == 'domain_name'
			|| $nodeName == 'top_domain_name') array_push($toremove, $node);
	}

	foreach($toremove as $item) {	
		$zdrojNode->removeChild($item);
	}


	$domName = getDomName($churl);
	$elem = $doc->createElement('domain_name', trim(htmlEscape($domName)));
	$zdrojNode->appendChild($elem);

	$elem = $doc->createElement('top_domain_name', trim(getTopDomain($domName)));
	$zdrojNode->appendChild($elem);



	$elem = $doc->createElement('IPs');
	
	foreach($ips as $ip) {
		$tmpElem = $doc->createElement('ip', trim($ip));
		$elem->appendChild($tmpElem);
	}

	$zdrojNode->appendChild($elem);

	
	$elem = $doc->createElement('realnames');
	
	foreach($realnames as $realname) {
		$tmpElem = $doc->createElement('realname', trim($realname));
		$elem->appendChild($tmpElem);
	}

	$zdrojNode->appendChild($elem);

	$elem = $doc->createElement('aliases');
	
	foreach($aliases as $alias) {
		$tmpElem = $doc->createElement('alias', trim($alias));
		$elem->appendChild($tmpElem);
	}

	$zdrojNode->appendChild($elem);

}

function setDates($doc, $dateElem, $nameDate, $urlDate, $ipsDate, $realDate, 
 $aliasDate) {
	
	$childs = $dateElem->childNodes;

	if ($nameDate != null) $childs->item(0)->nodeValue = $nameDate;
	if ($urlDate != null) $childs->item(1)->nodeValue = $urlDate;
	if ($ipsDate != null) $childs->item(2)->nodeValue = $ipsDate;
	if ($realDate != null) $childs->item(3)->nodeValue = $realDate;
	if ($aliasDate != null) $childs->item(4)->nodeValue = $aliasDate;

}

connect_db();

$what_query="zkratka,info_strucne,info_strucne_en,info_podrobne,info_podrobne_en,odkaz,modifikace,expirace,producent_nazev,producent_odkaz,odpovedny_spravce,kontaktni_osoba,zarazeni,jazyk,typ,aktivni,multioborovy,kategorie";

$query = "SELECT zdroj_id, $what_query".
	  " FROM zdroje WHERE $PUBLIC_SOURCE_COND ORDER BY zkratka";

$result = pg_query($query);

while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

	$id = $row['zdroj_id'];

	$vyraz = "/esources_IPs/esource[@source_id='$id']";
	$list = $xpath->evaluate($vyraz);


	$domName = getDomName($row['odkaz']);

	if ($list->length == 0) {

		$zdrojElem = $doc->createElement("esource");
		$zdrojElem->setAttribute("source_id", $row['zdroj_id']);

		$xmlElem = $doc->createElement('name', trim(htmlEscape($row['zkratka'])));
		$zdrojElem->appendChild($xmlElem);

		if ($row['producent_nazev'] != '') {
			$xmlElem = $doc->createElement('producer',  
				trim(htmlEscape($row['producent_nazev']))); 
			$zdrojElem->appendChild($xmlElem);
		}

		$xmlElem = $doc->createElement('url', trim(htmlEscape($row['odkaz'])));
		$zdrojElem->appendChild($xmlElem);


		$xmlElem = $doc->createElement('domain_name', trim(htmlEscape($domName)));
		$zdrojElem->appendChild($xmlElem);

		$xmlElem = $doc->createElement('top_domain_name', 
			trim(getTopDomain($domName)));
		$zdrojElem->appendChild($xmlElem);
		
		$xmlElem = $doc->createElement('dates');
		$zdrojElem->appendChild($xmlElem);

		$xmlElem->appendChild($doc->createElement('date_name'));
		$xmlElem->appendChild($doc->createElement('date_url'));
		$xmlElem->appendChild($doc->createElement('date_ips'));
		$xmlElem->appendChild($doc->createElement('date_realnames'));
		$xmlElem->appendChild($doc->createElement('date_aliases'));


		$addrs = array();
		$realnames = array();
		$aliases = array();

		getIPs($domName, $addrs, $realnames, $aliases, $k, $l);

		setDates($doc, $xmlElem, date($DATE_STRING), date($DATE_STRING), date($DATE_STRING), date($DATE_STRING), date($DATE_STRING));
		
		storeIPs($doc, $zdrojElem, $addrs, $realnames, $aliases, htmlEscape($row['odkaz']);

		$root->appendChild($zdrojElem);
	}
	// nalezneme zdroj, tak jej zpracuj
	else {
		// nejdriv vytahni udaje z XMLka
		$zdrojElem = $list->item(0);

		$childs = $zdrojElem->childNodes;

		for($i=0; $i<$childs->length; $i++) {

			if ($childs->item($i)->nodeName == 'name') {
				$nameNode = $childs->item($i);
				$name = $childs->item($i)->nodeValue;
			}
			else {
				if ($childs->item($i)->nodeName == 'url') {
					$urlNode = $childs->item($i);
					$url = $childs->item($i)->nodeValue;
				}
				else {
					if ($childs->item($i)->nodeName == 'realnames') {
						$realnamesNode = $childs->item($i);
					}
					else {
						if ($childs->item($i)->nodeName == 'IPs') {
							$ipsNode = $childs->item($i);
						}
						else {
							if ($childs->item($i)->nodeName == 'aliases') {
								$aliasesNode = $childs->item($i);
							}
							else {
								if ($childs->item($i)->nodeName == 'dates') {
									$datesNode = $childs->item($i);
								}
							}
						}
					}
				}
			}
		}

		// over zmeny v URL a nazvu 

		$nazev = htmlescape($row['zkratka']);
		$odkaz = htmlescape($row['odkaz']);
		$chname = false;
		$churl = false;

		if ($nazev != $name) {
			$nameNode->nodeValue = $nazev;
			$chname = true;
		}

		if ($odkaz != $url) {
			$urlNode->nodeValue = $odkaz;
			$churl = true;
		}

		$realnames = array();
		$ips = array();
		$aliases = array();

		// nezmenil-li se odkaz, pak budeme jen doplnovat
		if (! $churl) {
			$nodeChilds = $realnamesNode->childNodes;
			for ($i=0; $i<$nodeChilds->length; $i++) {
				array_push($realnames, $nodeChilds->item($i)->nodeValue);
			}

			$nodeChilds = $ipsNode->childNodes;
			for ($i=0; $i<$nodeChilds->length; $i++) {
				array_push($ips, $nodeChilds->item($i)->nodeValue);
			}

			$nodeChilds = $aliasesNode->childNodes;
			for ($i=0; $i<$nodeChilds->length; $i++) {
				array_push($aliases, $nodeChilds->item($i)->nodeValue);
			}
		}

		$chreal = false;
		$chalias = false;
		$changed = getIPs($domName, $ips, $realnames, $aliases, $chreal, $chalias);
		
		setDates($doc, $datesNode, 
			$chname ? date($DATE_STRING) : null, 
			$churl ? date($DATE_STRING) : null, 
			$changed ? date($DATE_STRING) : null,
			$chreal ? date($DATE_STRING) : null,
			$chalias ? date($DATE_STRING) : null);

		storeIPs($doc, $zdrojElem, $ips, $realnames, $aliases, $odkaz);

	}


}

$doc->save($xmlfile);
echo date($DATE_STRING). " $SCRIPT: Resources processed OK.\n";

?>
