<?php

require_once("eizlibs/db_connect.php");
require_once("eizlibs/functions.php");
require_once("lib/options_class.php");
require_once("eizlibs/object_class.php");
require_once("eizlibs/file_class.php");
require_once("eizlibs/config.php");

$VERSION='0.2';
$SCRIPT='export_sources_csv.php';

$singleoptions = array(
	'help' => option::newopt('h', 'help', 'vypise tuto napovedu'),
	'version' => option::newopt('V', 'version', 'vypise verzi skriptu'),
	'verbose' => option::newopt('v', 'verbose', 'podrobnejsi vypis provadenych operaci'),
	'justshow' => option::newopt('j', 'just-show', 'pouze simuluje (vypise) provadene operace'),
	'columns' => option::newopt('c:', 'columns:', 'seznam sloupcu, ktere se maji exportovat', 'column1[,column2[,column3 ...]]]'),
#	'delimiter' => option::newopt('d', 'delimiter', 'oddelovac poli (defaultne znak ","'),
	'sources' => option::newopt('S', 'sources', 'exportuj zdroje (defaultni nastaveni)'),
	'journals' => option::newopt('J', 'journals', 'exportuj caopisy'),
	'files' => option::newopt('d:', 'dir:', 'exportuj i neverejne soubory pro SFX (do adresare <dir>)', '<dir>'),
	'freetrials' => option::newopt('t', 'free-trials', 'exportovat i free-trial zdroje'),
	'usefullinks' => option::newopt('u', 'useful-links', 'exportovat i uzitecne odkazy'),
	'meta' => option::newopt('m', 'meta', 'exportovat i meta zdroje'),
	'free' => option::newopt('f', 'free', 'exportovat i volne dostupne zdroje'),
	'expired' => option::newopt('e', 'expired', 'exportovat i casove neplatne zdroje/casopisy (s vyprsenou platnosti)'),
	'nonactive' => option::newopt('n', 'nonactive', 'exportovat i neaktivni zdroje/casopisy'),
	'unionly' => option::newopt('U', 'university-only', 'exportovat pouze objekty dostupne z cele univerzity'),
	'availibility' => option::newopt('A', 'print-availibility', 'pridej seznam fakult, kde je objekt dostupny'),
	'all' => option::newopt('a', 'all', 'exportovat vse nezavisle na aktivaci, typu a dobe expirace')
);

$myoptions = options::getOptions($singleoptions);

if ($argc == 1 || $myoptions->isOpt($singleoptions['help'])) {
	echo "$SCRIPT (Portal EIZ)\n";
	echo "Verze: $VERSION\n";
	echo "Provadi export všech aktivních zdrojů nebo casopisu (nutno zadat volbu -J) do\nformatu CSV. Exportovane sloupce je treba specifikovat volbou -c (jejich nazvy\nodpovidaji prislusnym sloupcum v databazovych tabulkach 'zdroje' a 'casopisy'.\n";
	echo "Export je mozne konfigurovat nekolika volbami (-tumfen a -a) viz --help.\nDefaultne se exportuji licencovane aktivni neexpirovane zdroje/casopisy.";
	echo "Pouziti: php $SCRIPT [-adefhjJmnStuUvV] -c column1[,column2 ...]]\n";
	echo "Volby:\n";

	$myoptions->optionsHelp();

	exit(0);
}

if ($myoptions->isOpt($singleoptions['version'])) {
	echo "$SCRIPT, verze $VERSION\n";
	exit(0);
}

#if (! ($delimiter = $myoptions->isOpt($singleoptions['delimiter']))) {
#	$delimiter=',';
#}



$verbose = $myoptions->isOpt($singleoptions['verbose']);
$justshow = $myoptions->isOpt($singleoptions['justshow']);
$expired = $myoptions->isOpt($singleoptions['expired']);
$nonactive = $myoptions->isOpt($singleoptions['nonactive']);
$unionly = $myoptions->isOpt($singleoptions['unionly']);
$files = $myoptions->isOpt($singleoptions['files']);
$availibility = $myoptions->isOpt($singleoptions['availibility']);
$all = $myoptions->isOpt($singleoptions['all']);



$queryConds = array();
$queryKatConds = array();

if (! $all) {
	if (! $expired) $queryConds[] = 'expirace >= CURRENT_DATE';
	if (! $nonactive) $queryConds[] = "aktivni = 't'";
}
	
if ($files) {
	$dir = $myoptions->isOpt($singleoptions['files']);

	if (! is_dir($dir)) {
		if (! mkdir($dir)) {
			fwrite(STDERR, "Nemohu vytvorit adresar $dir\n");
			exit(1);
		}
	}
}

if (! ($columnsStr = $myoptions->isOpt($singleoptions['columns']))) {
	fwrite(STDERR, "Musite vlozit nazvy sloupcu, ktere se maji exportovat!\n");
	exit(1);
}

$columns = explode(',', $columnsStr);

$exportSources = true;
$exportJournals = false;



if ($myoptions->isOpt($singleoptions['journals'])) {
	$exportSources = false;
	$exportJournals = true;

	$queryTable = 'casopisy';
	$queryId = 'casopis_id';
	$queryTyp = eizObjekt::JOURNAL;

	if ($unionly) $queryConds[] = "mu = 't'";
}
else {
	$free = $myoptions->isOpt($singleoptions['free']);
	$freetrials = $myoptions->isOpt($singleoptions['freetrials']);
	$usefullinks = $myoptions->isOpt($singleoptions['usefullinks']);
	$meta = $myoptions->isOpt($singleoptions['meta']);

	$queryTable = 'zdroje';
	$queryId = 'zdroj_id';
	$queryTyp = eizObjekt::SOURCE;
	$queryConds[] = "povoleny = 't'";
	$queryKatConds[] = "kategorie = '". eizObjekt::KAT_LICENCOVANY ."'";

	if ($free) $queryKatConds[] = "kategorie = '". eizObjekt::KAT_FREE ."'";
	if ($freetrials) $queryKatConds[] = "kategorie = '". eizObjekt::KAT_FREE_TRIAL ."'";
	if ($usefullinks) $queryKatConds[] = "kategorie = '". eizObjekt::USEFUL ."'";
	if ($meta) $queryKatConds[] = "kategorie = '". eizObjekt::KAT_META ."'";

	if ($unionly) $queryConds[] = "zarazeni = $SOURCE_MU";
}

connect_db();

$sqlcond = '';

if (count($queryConds) > 1) {
	$sqlcond = ' WHERE (' . $queryConds[0] . ')';

	for($i = 1; $i<count($queryConds); $i++) {
		$sqlcond .= ' AND (' . $queryConds[$i] . ')';
	}
}

if (count($queryKatConds) > 1) {
	if (strlen($sqlcond) == 0) {
		$sqlcond .= ' WHERE ((' . $queryKatConds[0] . ')';	
	}
	else {
		$sqlcond .= ' AND ((' . $queryKatConds[0] . ')';
	}

	for($i = 1; $i<count($queryConds); $i++) {
		$sqlcond .= ' OR (' . $queryConds[$i] . ')';
	}

	$sqlcond .= ')';
}


$query = "SELECT $queryId,$columnsStr FROM $queryTable $sqlcond ORDER BY ${columns[0]}";

if ($verbose || $justshow) {
	echo "$query\n";
}

if (! $justshow) {
	$result = pg_query($query);

	while ($row = pg_fetch_array($result, NULL, PGSQL_ASSOC)) {

		$line = '';
		foreach($columns as $col) {
			$line .= CSVval($row[$col]) . ",";
		}

		echo "$line";
		#echo substr($line, -1) . "\n";

		if ($files) {

			$filesObj = soubor::getFilesFor($row[$queryId], $queryTyp);

			foreach($filesObj as $file) {

				if (stristr($file->popis, 'sfx')) {

					$source = $file->getFilePath();
					$destination = $dir.'/'.$file->normalizeFileName();

					if (! copy($source, $destination)) {
						fwrite(STDERR, "Nepodarilo se nakopirovat soubor ". $source . 
							" do " . $destination . "\n");
					}

					echo ",".$file->normalizeFileName();
				}
			}
		}
		echo "\n";
	}


}




function CSVval($str) {

	$str = str_replace('"', '""', $str);

	if (strstr($str, ' ') || strstr($str, '"') || strstr($str, ',')) $str = '"' . $str . '"';

	return $str;
}


?>
