<?php

// trida reprezentuje radkovou option
class option {

const NONE = '';

private $shortopt;
private $longopt;
private $help;
private $helpparam;
private $shortclean;
private $longclean;

private function __construct($shortopt, $longopt, $help, $helpparam) {
	
	$this->shortopt = $shortopt;
	$this->longopt = $longopt;
	$this->help = $help;
	$this->helpparam = $helpparam;
	$this->shortclean = str_replace(':', '', $shortopt);
	$this->longclean = str_replace(':', '', $longopt);
}

public static function newopt($shortopt, $longopt, $help, 
	$helpparam = self::NONE) {

	if (strpos($shortopt, ':') !== false && $helpparam == self::NONE) {
			echo "WARNING: Parameter specified in option ($shortopt, $longopt), but helpparam in newopt() not given!\n";
	}

	return new option($shortopt, $longopt, $help, $helpparam);
}

public function opthelp() {

	if ($this->helpparam != '') {
		$shorthelpparam = ' '.$this->helpparam;
		$longhelpparam = '='.$this->helpparam;
	}
	else {
		$shorthelpparam = '';
		$longhelpparam = '';
	}

	if ($this->shortopt != '') {
		$shortopt = "-".$this->shortclean.$shorthelpparam;
	}
	else {
		$shortopt = '';
	}

	if ($this->longopt != '') {
		$longopt = "--".$this->longclean.$longhelpparam;
	}
	else {
		$longopt = '';
	}
	
	if ($longopt != '' && $shortopt != '') {
		echo $shortopt.", ".$longopt."\n";
	}
	else {
		echo $shortopt.$longopt."\n";
	}

	echo "    $this->help\n";
}

public function getshort() {

	return $this->shortopt;
}

public function getlong() {

	return $this->longopt;
}

public function getshortclean() {

	return $this->shortclean;
}

public function getlongclean() {

	return $this->longclean;
}

public function isParam() {

	return $this->helpparam == self::NONE ? false : true;
}	

}

class options {

private $shortopts;
private $longopts;
private $singleoptions;
private $options;

private function __construct($options) {

	foreach($options as $option) {
	
		$this->shortopts .= $option->getshort();
		$this->longopts[] = $option->getlong();
		$this->singleoptions[] = $option;
	}

	$this->options = getopt($this->shortopts, $this->longopts);
}

public static function getOptions($options) {

	return new options($options);
}

public function getShortOpts() {

	return $shortopts;
}

public function getLongOpts() {

	return $longopts;
}


public function isOpt($option) {

	$shortopt = $option->getshortclean();
	$longopt = $option->getlongclean();


	if ($option->isParam()) {

		if (isset($this->options[$shortopt])) {
			return $this->options[$shortopt];
		}
		
		if (isset($this->options[$longopt])) {
			return $this->options[$longopt];
		}
	
		return false;
	}
	else {

		if (isset($this->options[$shortopt])) return true;
		if (isset($this->options[$longopt])) return true;
	}

	return false;
}

public function optionsHelp() {

	foreach($this->singleoptions as $option) {
		$option->opthelp();
	}
}


}
